/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数
********************************************************************************/

/********************************INCLUDES*************************************/
#include <stdio.h>
#include "Periph.h"
#include "CommDef.h"

volatile unsigned char temp_s0     = 0;
volatile unsigned char temp_s1     = 0;
volatile unsigned char temp_s2     = 0;
volatile unsigned char ADON2_1     = 0;
volatile unsigned char ADON2_2     = 0;


//==============================================================================================
// ----Function: GPIO初始化设置
// --Parameters: None
// -----Returns: None
//---------Note: 该函数为内部函数，当调用Config_ADC或Config_AUTO_ADC函数后可自动初始化AD通道对应
//               的GPIO
//==============================================================================================
void Config_AD_GPIO(unsigned char TEMP_c)
{
   //将对应通道的I/O口设置为输入模式，关闭上下拉，关闭开漏，然后使能该口的模拟功能
   switch(TEMP_c)
   {
	  case  0:{TRISA3 = 1;PA3PD = 1;PA3PU = 1;PA3OD = 0;PA3AEN = 1;}break;
	  case  1:{TRISA2 = 1;PA2PD = 1;PA2PU = 1;PA2OD = 0;PA2AEN = 1;}break;
	  case  2:{TRISA1 = 1;PA1PD = 1;PA1PU = 1;PA1OD = 0;PA1AEN = 1;}break;
	  case  3:{TRISA0 = 1;PA0PD = 1;PA0PU = 1;PA0OD = 0;PA0AEN = 1;}break;
	  case  4:{TRISB0 = 1;PB0PD = 1;PB0PU = 1;PB0OD = 0;PB0AEN = 1;}break;
	  case  5:{TRISB1 = 1;PB1PD = 1;PB1PU = 1;PB1OD = 0;PB1AEN = 1;}break;
	  case  6:{TRISB5 = 1;PB5PD = 1;PB5PU = 1;PB5OD = 0;PB5AEN = 1;}break;
	  case  7:{TRISC1 = 1;PC1PD = 1;PC1PU = 1;PC1OD = 0;PC1AEN = 1;}break;
	  case  8:{TRISC0 = 1;PC0PD = 1;PC0PU = 1;PC0OD = 0;PC0AEN = 1;}break;
	  case  9:{TRISA5 = 1;PA5PD = 1;PA5PU = 1;PA5OD = 0;PA5AEN = 1;}break;
	  case 13:{TRISB2 = 1;PB2PD = 1;PB2PU = 1;PB2OD = 0;PB2AEN = 1;}break;
	  default: break;
   }
}

//==============================================================================================
// ----Function: Config_ADC
// --Parameters:
//【Channel】：AD转换通道设置（可选如下）
//
//            AD_CH0_PA3： ADC通道 0（PA3）
//            AD_CH1_PA2： ADC通道 1（PA2）
//            AD_CH2_PA1： ADC通道 2（PA1）
//            AD_CH3_PA0： ADC通道 3（PA0）
//            AD_CH4_PB0： ADC通道 4（PB0）
//            AD_CH5_PB1： ADC通道 5（PB1）
//            AD_CH6_PB5： ADC通道 6（PB5）
//            AD_CH7_PC1： ADC通道 7（PC1）
//            AD_CH8_PC0： ADC通道 8（PC0）
//            AD_CH9_PA5： ADC通道 9（PA5）
//   AD_CH10_BUFFER_UNIT： ADC通道10（BUFFER_UNIT）
//        AD_CH11_OP1OUT： ADC通道11（OP1OUT）
//        AD_CH12_OP0OUT： ADC通道12（OP0OUT）
//           AD_CH13_PB2： ADC通道13（PB2）
//       AD_CH14_DAC0OUT： ADC通道14（DAC0OUT）
//        AD_CH15_FVROUT： ADC通道15（FVROUT）
//
//【Vref_Volt】：ADC参考电压选择（可选如下）
//
//           AD_Vref_FVR：参考电压为FVR
//           AD_Vref_VCC：参考电压为VCC
//       AD_Vref_OP0_OUT：参考电压为OP0_OUT
//           AD_Vref_PB0：参考电压为PB0口输入电压
//
//【AD_ACQT】：ADC采集时间选择（可选如下）
//
//                AD_0TAD： 0 TAD
//                AD_2TAD： 2 TAD
//                AD_4TAD： 4 TAD
//                AD_6TAD： 6 TAD
//                AD_8TAD： 8 TAD
//               AD_10TAD：10 TAD
//               AD_12TAD：12 TAD
//               AD_14TAD：14 TAD
//
//【AD_CS】：ADC转换时钟选择（可选如下）
//
//   AD_FSYS_16_or_FSYS_2：FSYS/16(ADSP=0) ，FSYS/2(ADSP=1)
//   AD_FSYS_32_or_FSYS_8：FSYS/32 (ADSP=0)，FSYS/8(ADSP=1)
// AD_FSYS_256_or_FSYS_32：FSYS/256(ADSP=0)，FSYS/32(ADSP=1)
//   AD_FSYS_32_or_FSYS_4：FSYS/32(ADSP=0) ，FSYS/4(ADSP=1)
// AD_FSYS_128_or_FSYS_16：FSYS/128(ADSP=0)，FSYS/16(ADSP=1)
// AD_FSYS_512_or_FSYS_64：FSYS/512(ADSP=0)，FSYS/64(ADSP=1)
//
//【AD_Pri_INT】：AD中断设置
//
//				  INT_OFF：禁用AD中断
//				H_Pri_INT：使能AD高优先级中断:
//			    L_Pri_INT：使能AD低优先级中断
//
// -----Returns: None
//---------Note: 该函数可设置AD转换的通道、参考电压、采集时间、转换时钟并使能ADC模块
//==============================================================================================
void Config_ADC(unsigned char Channel,unsigned char Vref_Volt,unsigned char AD_ACQT,unsigned char AD_CS,unsigned char AD_Pri_INT)
{
   unsigned char Temp = 0;

   temp_s0 = 0;
   temp_s1 = 0;

   //以下为超限判断，如果超出则设置一个默认值，防止用户设置超过范围的值导致系统出错
   if(Channel   > 15 )Channel   = AD_CH0_PA3;
   if(Vref_Volt >  3 )Vref_Volt = AD_Vref_VCC;
   if(AD_ACQT   >  7 )AD_ACQT   = AD_14TAD;
   if(AD_CS     >  7 )AD_CS     = AD_FSYS_512_or_FSYS_64;

   //设置AD转换使用到的GPIO通道
   Config_AD_GPIO(Channel);

   temp_s0 |= Channel   << 2;  //写入A/D转换通道设置值到ADCON0[5:2]
   temp_s1 |= Vref_Volt << 6;  //写入A/D转换参考电压设置到ADCON1[7:6]
   temp_s1 |= AD_ACQT   << 3;  //写入A/D转换时间设置到ADCON1[5:3]
   temp_s1 |= AD_CS;           //写入A/D转换时钟设置到ADCON1[2:0]

   ADCON0 = temp_s0;
   ADCON1 = temp_s1;

   ADFM    = 0;               //ADC转结果右对齐，即ADRESH = {4’b0,adc【11:8】}，ADRESL = adc【7:0】
   ADON    = 1;               //使能ADC模块

    printf("/***********ADC***********/\r\n");
    Temp = 0;Temp = ADCON0;
	printf("ADCON0   = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCON1;
	printf("ADCON1   = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCMP0H;
	Temp = 0;Temp = ADCMP1H;
	Temp = 0;Temp = ADCMP01L;
	Temp = 0;

   	//AD中断设置
	     if(AD_Pri_INT == H_Pri_INT){ADIF = 0;ADIP = 1;ADIE = 1;printf("ADIF     = 0;\r\nADIP     = 1;\r\nADIE     = 1;\r\n");}
	else if(AD_Pri_INT == L_Pri_INT){ADIF = 0;ADIP = 0;ADIE = 1;printf("ADIF     = 0;\r\nADIP     = 0;\r\nADIE     = 1;\r\n");}
	else {ADIF = 0;ADIP = 1;ADIE = 0;printf("ADIF     = 0;\r\nADIP     = 1;\r\nADIE     = 0;\r\n");}

    printf("/***********ADC***********/\r\n");
}

//==============================================================================================
// ----Function: ADC_CH_ICR
// --Parameters:
//【Channel】：AD转换通道设置（可选如下）
//
//            AD_CH0_PA3： ADC通道 0（PA3）
//            AD_CH1_PA2： ADC通道 1（PA2）
//            AD_CH2_PA1： ADC通道 2（PA1）
//            AD_CH3_PA0： ADC通道 3（PA0）
//            AD_CH4_PB0： ADC通道 4（PB0）
//            AD_CH5_PB1： ADC通道 5（PB1）
//            AD_CH6_PB5： ADC通道 6（PB5）
//            AD_CH7_PC1： ADC通道 7（PC1）
//            AD_CH8_PC0： ADC通道 8（PC0）
//            AD_CH9_PA5： ADC通道 9（PA5）
//   AD_CH10_BUFFER_UNIT： ADC通道10（BUFFER_UNIT）
//        AD_CH11_OP1OUT： ADC通道11（OP1OUT）
//        AD_CH12_OP0OUT： ADC通道12（OP0OUT）
//           AD_CH13_PB2： ADC通道13（PB2）
//       AD_CH14_DAC0OUT： ADC通道14（DAC0OUT）
//        AD_CH15_FVROUT： ADC通道15（FVROUT）
//
// -----Returns: None
//---------Note: None
//==============================================================================================
void ADC_CH_ICR(unsigned char Channel)
{
    //以下为超限判断，如果超出则设置一个默认值，防止用户设置超过范围的值导致系统出错
	if(Channel   > 15 )Channel   = AD_CH0_PA3;

    //设置AD转换使用到的GPIO通道
    Config_AD_GPIO(Channel);
}


//==============================================================================================
// ----Function: 启动AD转换
// --Parameters: None
// -----Returns: None
//---------Note: 每次转换前需调用该函数以启动AD转换
//==============================================================================================
void ADC_Start(void)
{
   GO = 1;
}

//==============================================================================================
// ----Function: ADC_SampleFilter
// --Parameters: None
// -----Returns: None
//---------Note: 该函数用于AD转转换的结果获取
//               *该函数采用了Time_OUT方式防止AD转换因为静电等原因导致的运行异常，一旦出现这种情况则重新启动AD转换；
//               *该函数使用了平滑滤波算法，以保证输出的数据稳定，该算法不一定适用于所有情况，请更具实际情况选择对应的算法；
//==============================================================================================
volatile unsigned short VoltBuf[8] = 0;
volatile unsigned char  VoltInx    = 0;
unsigned short ADC_SampleFilter(void)
{
   unsigned char  i,j;
   unsigned short Volt 		 = 0;
   unsigned char  Time_Out   = 0;
   unsigned short Sum        = 0;

   for(j = 0;j<=5;j++)
   {
	  GO = 1;                 //启动一次转换
	  Time_Out = 100;         //设置超时时间
	  while(GO)               //等待转换结束
	  {
		 Time_Out--;          //等待超时
		 if(Time_Out == 0)    //防止程序跑到这里死掉了
		 {
			ADON = 0;         //先关闭AD转换
			GO = 0;           //清除转换标志
			ADON = 1;         //在重新开启AD转换
			GO = 1;           //清除转换标志
		 }
	  }
   }

   Volt = (ADRESH<<8)|ADRESL;//取出AD转换的值
   //以下为平滑滤波算法
   VoltBuf[VoltInx] = Volt;
   VoltInx++;
   if(VoltInx > 7)
   {
	  VoltInx = 0;
   }
   for(i = 0;i <= 7;i++)
   {
	  Sum += VoltBuf[i];
   }
   Volt = (Sum >> 3)&0xFFF;
   return Volt;
}

/*******************************************************************************
* Description    : 设置系统优先级总中断
* Input          : [INT_cfg]:
*                            H_SysPri_INIT_EN : 使能高优先级中断
*                            H_SysPri_INIT_Dis: 禁用高优先级中断
*                            L_SysPri_INIT_EN : 使能低优先级中断
*                            L_SysPri_INIT_Dis: 禁用低优先级中断
* Return         : None.
* Note           : None.
*******************************************************************************/
void System_INIT_Config(unsigned char INT_cfg)
{
	printf("/*********SYS_INT*********/\r\n");
    if(INT_cfg == H_SysPri_INIT_EN)
	{
		printf("IPEN     = 1;\r\nGIEH     = 1;\r\n");
	   	IPEN = 1;	   //使能中断优先级
	    GIEH = 1;      //使能高优先级全局中断
	}else if(INT_cfg == H_SysPri_INIT_Dis)
	{
		printf("IPEN     = 1;\r\nGIEH     = 0;\r\n");
	   	IPEN = 1;	   //使能中断优先级
	    GIEH = 0;      //禁用高优先级全局中断
	}else if(INT_cfg == L_SysPri_INIT_EN)
	{
		printf("IPEN     = 1;\r\nGIEL     = 1;\r\n");
	   	IPEN = 1;	   //使能中断优先级
	    GIEL = 1;      //使能低优先级全局中断
	}else if(INT_cfg == L_SysPri_INIT_Dis)
	{
	    printf("IPEN     = 1;\r\nGIEL     = 0;\r\n");
	   	IPEN = 1;	   //使能中断优先级
	    GIEL = 0;      //禁用低优先级全局中断
	}
	printf("/*********SYS_INT*********/\r\n");
}
