/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 202012001
* Description :
* Note		  : ADC采集值大于3500产生ADCMP1中断,并使PB3翻转、AD值小于1500产生ADCMP0中断,并使PB4翻转
*               ADC通道：PA5
*               urat-PB0 输出          对应电压ADC值与相应的电压值   波特率 = 19200
********************************************************************************/

/********************************INCLUDES*************************************/

#include <math.h>
#include <stdio.h>
#include "AD18F02x.h"	//系统头文件
#include "CommDef.h"
#include "Common.h"
#include "Periph.h"
#include "usart.h"

/********************************配置字*************************************/
/***************************************************************************
*	常用配置字功能说明：
*
*	_FINTOSC_DIV1_1L：系统时钟选择--系统时钟不分频
*	_LVREN_ON_1L	: 掉电复位（Brown-out Reset）开关打开
*	_LVT24V_1L		：掉电复位电压选择 2.4v

*	_DBG_OFF_2L			: DEBUG 模式使能位， 使能后将固定 PA2 和 PA3 为 DEBUG IO
*	_FLASH_CP3_OFF_2L	：关闭0~1K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写
*	_FLASH_CP2_OFF_2L	：关闭1~2K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写
*	_FLASH_CP1_OFF_2L	: 关闭2~3K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写
*	_FLASH_CP0_OFF_2L	: 关闭3~4K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写

*	_CRYLEN_OFF_2L	: 禁止外部晶体低频振荡器
*	_CRYHEN_OFF_2L	：禁止外部晶体高频振荡器
*	_IDIS_OFF_2L	：关闭IO打开模拟功能时读取电平功能
*	_CKSUM_OFF_2L	: 关闭校验
*	_CBP_OFF_2L		: 代码不加密
*	_RESETE_OFF_2L	：复位脚禁止
*	_RSEL_LOW_2L	：端口上下拉选择30K
*	_STV_ON_2L		：堆栈溢出复位使能

*	_PSUT_1_3L		: 上电复位时间选择
*	_FCPU_4T_3L		: MCU选择4T模式
*	_WDTEN_OFF_3L	：WDT关闭
*	_TWDT_000_3L	：WDT溢出时间不分频

*	_OSCM_HIRC_16M_4L	：主时钟选择高速内部时钟---16MHz
*	_FCMEN_OFF_4L		: 禁止系统时钟失效监测，仅在系统时钟为外部晶振模式作用
*	_IESO_OFF_4L		：关闭双速启动模式， 仅在系统时钟为外部晶振模式才起作用
*	_ADCSP_ON_4L		: ADC 采集速度设置为高速

*	注意：1.配置字若无特别需求请勿修改；
*			2.其他配置字及相应功能见Datasheet及头文件；
*
****************************************************************************/
__CONFIG(1,_FINTOSC_DIV1_1L     & _LVREN_OFF_1L      & _LVT24V_1L                                                                                                 );
__CONFIG(2,_DBG_OFF_2L          & _FLASH_CP3_OFF_2L & _FLASH_CP2_OFF_2L & _FLASH_CP1_OFF_2L  &_FLASH_CP0_OFF_2L
		  &_CRYLEN_OFF_2L       & _CRYHEN_OFF_2L    & _IDIS_OFF_2L      & _CKSUM_OFF_2L      & _CBP_OFF_2L       & _RESETE_OFF_2L  & _RSEL_LOW_2L  & _STV_ON_2L  );
__CONFIG(3,_PSUT_32_3L           & _FCPU_2T_3L       & _WDTEN_OFF_3L     & _TWDT_011_3L                                                                           );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _FCMEN_OFF_4L     & _IESO_OFF_4L      & _ADCSP_ON_4L                                                                           );

/*******************************MACROS_USR************************************/
/********************************TYPEDEFS*************************************/
/********************************CONSTANTS************************************/
/****************************EXTERNAL FUNCTIONS*******************************/
/*****************************LOCAL FUNCTIONS*********************************/
/****************************EXTERNAL VARIABLES*******************************/
/******************************LOCAL VARIABLES********************************/
/*****************************GLOBAL VARIABLES********************************/
void main(void)
{
    double AD_Temp;
    unsigned short Val = 0;
    unsigned long  V;
    unsigned char ge,shi,bai,qian;

	//GPIO初始化
    GPIO_Init();

	//UART初始化  PB0_TX,PB1_RX,
    Com_Init();
	printf("ADC_TEST...\r\n\r\n");

	//ADC初始化  ADC通道 9（PA5） 参考电压为VCC   ADC采集时间为14TAD     ADC转换时钟为FOSC_64    禁用ADC中断
	Config_ADC(    AD_CH9_PA5,     AD_Vref_VCC,       AD_14TAD,         AD_FSYS_512_or_FSYS_64,    INT_OFF);

    //ADC比较中断设置      ADC比较模式0    达到1次就触发中断    AD值大于3500产生ADCMP1中断     AD值小于1500产生ADCMP0中断    ADCMP优先级为高优先级，使能中断
	Config_ADCMP_Interrupt(AD_CMP_MODE_0,     AD_CMP_ACN1,                  3500,                          1500,                     H_Pri_INT);

    //使能高优先级中断
    System_INIT_Config(H_SysPri_INIT_EN);
	while(1)
	{
	    ADC_Start();
		while(GO==1);
		Val = (ADRESH<<8)|ADRESL;
		AD_Temp = (Val/4096.0*5)*1000;
		V = (long)AD_Temp;
		qian=V%10000/1000;
		bai =V%1000/100;
		shi =V%100/10;
		ge  =V%10;
		printf("VOLT = %d;",Val);
		printf("V = ");
		printf("%d",qian);
		printf(".");
		printf("%d",bai);
		printf("%d",shi);
		printf("%d;\r\n",ge);
	}
}

//高优先级中断服务函数
void interrupt ISR_h (void)
{
	if(ADCMP1IE == 1 && ADCMP1IF == 1 && ADCMP1IP == 1)
    {
       ADCMP1IF    = 0;
       PB3 = ~PB3;
    }
	if(ADCMP0IE == 1 && ADCMP0IF == 1 && ADCMP0IP == 1)
    {
       ADCMP0IF    = 0;
       PB4 = ~PB4;
    }
}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{

}

