/*********************************************************************************************
* Device      : AD18F02
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数头文件
*********************************************************************************************/


#ifndef __PERIPH_H__
#define __PERIPH_H__

#include <stdio.h>
#include "AD18F02x.h"
#include "Periph.h"
#include "Common.h"
#include "CommDef.h"

#define           AD_Vref_FVR           0   //设置ADC的参考电压为FVR
#define           AD_Vref_VCC           1   //设置ADC的参考电压为VCC
#define           AD_Vref_OP0_OUT       2   //设置ADC的参考电压为OP0_OUT
#define           AD_Vref_PB0           3   //设置ADC的参考电压为PB0口输入电压

#define           AD_CH0_PA3            0   //ADC通道 0（PA3）
#define           AD_CH1_PA2            1   //ADC通道 1（PA2）
#define           AD_CH2_PA1            2   //ADC通道 2（PA1）
#define           AD_CH3_PA0            3   //ADC通道 3（PA0）
#define           AD_CH4_PB0            4   //ADC通道 4（PB0）
#define           AD_CH5_PB1            5   //ADC通道 5（PB1）
#define           AD_CH6_PB5            6   //ADC通道 6（PB5）
#define           AD_CH7_PC1            7   //ADC通道 7（PC1）
#define           AD_CH8_PC0            8   //ADC通道 8（PC0）
#define           AD_CH9_PA5            9   //ADC通道 9（PA5）
#define           AD_CH10_BUFFER_UNIT  10   //ADC通道10（BUFFER_UNIT）
#define           AD_CH11_OP1OUT       11   //ADC通道11（OP1OUT）
#define           AD_CH12_OP0OUT       12   //ADC通道12（OP0OUT）
#define           AD_CH13_PB2          13   //ADC通道13（PB2）
#define           AD_CH14_DAC0OUT      14   //ADC通道14（DAC0OUT）
#define           AD_CH15_FVROUT       15   //ADC通道15（FVROUT）

#define           AD_0TAD               0   // 0TAD
#define           AD_2TAD               1   // 2TAD
#define           AD_4TAD               2   // 4TAD
#define           AD_6TAD               3   // 6TAD
#define           AD_8TAD               4   // 8TAD
#define           AD_10TAD              5   //10TAD
#define           AD_12TAD              6   //12TAD
#define           AD_14TAD              7   //14TAD

//配置字:  ADSP_OFF   ADSP_ON
#define           AD_FSYS_16_or_FSYS_2      0   //配置字ADSP_OFF时,ADC转换时钟为FSYS/16 ,ADSP_ON时,ADC转换时钟为FSYS/2
#define           AD_FSYS_32_or_FSYS_8      1   //配置字ADSP_OFF时,ADC转换时钟为FSYS/32 ,ADSP_ON时,ADC转换时钟为FSYS/8
#define           AD_FSYS_256_or_FSYS_32    2   //配置字ADSP_OFF时,ADC转换时钟为FSYS/256,ADSP_ON时,ADC转换时钟为FSYS/32
#define           AD_FSYS_32_or_FSYS_4      4   //配置字ADSP_OFF时,ADC转换时钟为FSYS/32 ,ADSP_ON时,ADC转换时钟为FSYS/4
#define           AD_FSYS_128_or_FSYS_16    5   //配置字ADSP_OFF时,ADC转换时钟为FSYS/128,ADSP_ON时,ADC转换时钟为FSYS/16
#define           AD_FSYS_512_or_FSYS_64    6   //配置字ADSP_OFF时,ADC转换时钟为FSYS/512,ADSP_ON时,ADC转换时钟为FSYS/64

#define           AD_CMP_MODE_0         0   //采集值大于ADCMP1[H:L]产生中断ADCMP1IF,小于ADCMP0[H:L]产生中断ADCMP0IF
#define           AD_CMP_MODE_1         1   //采集值小于ADCMP1[H:L]且大于ADCMP0[H:L]，产生中断ADCMP0IF

#define           AD_CMP_ACN1           0   //当ADC采样值与比较值符合条件1次时,触发比较中断标志ADCMP0IF
#define           AD_CMP_ACN2           1   //当ADC采样值与比较值符合条件2次时,触发比较中断标志ADCMP0IF
#define           AD_CMP_ACN4           2   //当ADC采样值与比较值符合条件4次时,触发比较中断标志ADCMP0IF
#define           AD_CMP_ACN8           3   //当ADC采样值与比较值符合条件8次时,触发比较中断标志ADCMP0IF

#define           AD_INT_ENABLE         1   //使能ADC中断
#define           AD_INT_DISABLE        0   //禁止ADC中断

/*********************************************中断设置**************************************/
#define           H_SysPri_INIT_EN       0  //使能高优先级中断
#define           H_SysPri_INIT_Dis      1  //禁用高优先级中断
#define           L_SysPri_INIT_EN       2  //使能低优先级中断
#define           L_SysPri_INIT_Dis      3  //禁用低优先级中断

#define           INT_OFF                0  //禁用外设中断
#define           H_Pri_INT              1  //外设使能高优先级中断
#define           L_Pri_INT              2  //外设使能低优先级中断
/*********************************************中断设置**************************************/

#define           PWM10_HTOL_EDGE        0
#define           PWM10_LTOH_EDGE        1

#define           FDT_Fsys               0
#define           FDT_Fsys_2             1
#define           FDT_Fsys_4             2
#define           FDT_Fsys_8             3

#define           PWM_CPMT               0
#define           UP_ARM                 1
#define           DW_ARM                 2

#define           SEL_cfg                3

#define           SEL_UP_DW_OFF          0
#define           SEL_UP_OFF_DW_ON       1
#define           SEL_UP_ON_DW_OFF       2
#define           SEL_UPDW_Mw_OFF        3

#define           OUT_1                  1
#define           OUT_0                  0

#define           PB2_OUT	             1
#define           PC2_OUT                0


//==============================================================================================
// ----Function: Config_ADC
// --Parameters:
//【Channel】：AD转换通道设置（可选如下）
//
//            AD_CH0_PA3： ADC通道 0（PA3）
//            AD_CH1_PA2： ADC通道 1（PA2）
//            AD_CH2_PA1： ADC通道 2（PA1）
//            AD_CH3_PA0： ADC通道 3（PA0）
//            AD_CH4_PB0： ADC通道 4（PB0）
//            AD_CH5_PB1： ADC通道 5（PB1）
//            AD_CH6_PB5： ADC通道 6（PB5）
//            AD_CH7_PC1： ADC通道 7（PC1）
//            AD_CH8_PC0： ADC通道 8（PC0）
//            AD_CH9_PA5： ADC通道 9（PA5）
//   AD_CH10_BUFFER_UNIT： ADC通道10（BUFFER_UNIT）
//        AD_CH11_OP1OUT： ADC通道11（OP1OUT）
//        AD_CH12_OP0OUT： ADC通道12（OP0OUT）
//           AD_CH13_PB2： ADC通道13（PB2）
//       AD_CH14_DAC0OUT： ADC通道14（DAC0OUT）
//        AD_CH15_FVROUT： ADC通道15（FVROUT）
//
//【Vref_Volt】：ADC参考电压选择（可选如下）
//
//            AD_Vref_FVR：参考电压为FVR
//            AD_Vref_VCC：参考电压为VCC
//        AD_Vref_OP0_OUT：参考电压为OP0_OUT
//            AD_Vref_PB0：参考电压为PB0口输入电压
//
//【AD_ACQT】：ADC采集时间选择（可选如下）
//
//                AD_0TAD： 0 TAD
//                AD_2TAD： 2 TAD
//                AD_4TAD： 4 TAD
//                AD_6TAD： 6 TAD
//                AD_8TAD： 8 TAD
//               AD_10TAD：10 TAD
//               AD_12TAD：12 TAD
//               AD_14TAD：14 TAD
//
//【AD_CS】：ADC转换时钟选择（可选如下）
//
//           AD_FSYS_16_or_FSYS_2      0   //配置字ADSP_OFF时,ADC转换时钟为FSYS/16 ,ADSP_ON时,ADC转换时钟为FSYS/2
//           AD_FSYS_32_or_FSYS_8      1   //配置字ADSP_OFF时,ADC转换时钟为FSYS/32 ,ADSP_ON时,ADC转换时钟为FSYS/8
//           AD_FSYS_256_or_FSYS_32    2   //配置字ADSP_OFF时,ADC转换时钟为FSYS/256,ADSP_ON时,ADC转换时钟为FSYS/32
//           AD_FSYS_32_or_FSYS_4      4   //配置字ADSP_OFF时,ADC转换时钟为FSYS/32 ,ADSP_ON时,ADC转换时钟为FSYS/4
//           AD_FSYS_128_or_FSYS_16    5   //配置字ADSP_OFF时,ADC转换时钟为FSYS/128,ADSP_ON时,ADC转换时钟为FSYS/16
//           AD_FSYS_512_or_FSYS_64    6   //配置字ADSP_OFF时,ADC转换时钟为FSYS/512,ADSP_ON时,ADC转换时钟为FSYS/64
//
//【AD_Pri_INT】：AD中断设置
//
//				  INT_OFF：禁用AD中断
//				H_Pri_INT：使能AD高优先级中断:
//			    L_Pri_INT：使能AD低优先级中断
//
// -----Returns: None
//---------Note: 该函数可设置AD转换的通道、参考电压、采集时间、转换时钟并使能ADC模块
//==============================================================================================
void Config_ADC(unsigned char Channel,unsigned char Vref_Volt,unsigned char AD_ACQT,unsigned char AD_CS,unsigned char AD_Pri_INT);

//==============================================================================================
// ----Function: Config_ADCMP_Interrupt
// --Parameters:
//【ADCMP_MODE】:ADC比较模式设置
//
// AD_CMP_MODE_0：ADC比较模式0,即“采集值大于ADCMP1[H:L]产生中断ADCMP1IF,小于ADCMP0[H:L]产生中断ADCMP0IF”;
// AD_CMP_MODE_1：ADC比较模式1,即“采集值小于ADCMP1[H:L]且大于ADCMP0[H:L]，产生中断ADCMP0IF”;
//
//【ADCMP_ACN】:当ADC采样值符合条件达到指定次数时,触发比较中断标志ADCMP0IF
//
//   AD_CMP_ACN1：当ADC采样值与比较值符合条件1次时,触发比较中断标志ADCMP0IF
//   AD_CMP_ACN2：当ADC采样值与比较值符合条件2次时,触发比较中断标志ADCMP0IF
//   AD_CMP_ACN4：当ADC采样值与比较值符合条件4次时,触发比较中断标志ADCMP0IF
//   AD_CMP_ACN8：当ADC采样值与比较值符合条件8次时,触发比较中断标志ADCMP0IF
//
//【Value_1】:ADC比较器的比较值(设置范围0-4095),详见手册比较模式设置说明
//【Value_0】:ADC比较器的比较值(设置范围0-4095),详见手册比较模式设置说明
//
//【AD_Pri_INT】：AD中断设置
//
//				  INT_OFF：禁用AD中断
//				H_Pri_INT：使能AD高优先级中断:
//			    L_Pri_INT：使能AD低优先级中断
//
// -----Returns: None
//---------Note: 该函数可设置AD转换的比较中断功能

//==============================================================================================
void Config_ADCMP_Interrupt(unsigned char ADCMP_MODE,unsigned char ADCMP_ACN,unsigned short Value_1,unsigned short Value_0,unsigned char AD_Pri_INT);

//==============================================================================================
// ----Function: 启动AD转换
// --Parameters: None
// -----Returns: None
//---------Note: 每次转换前需调用该函数以启动AD转换
//==============================================================================================
void ADC_Start(void);

//==============================================================================================
// ----Function: ADC_SampleFilter
// --Parameters: None
// -----Returns: None
//---------Note: 该函数用于AD转转换的结果获取
//               *该函数采用了Time_OUT方式防止AD转换因为静电等原因导致的运行异常，一旦出现这种情况则重新启动AD转换；
//               *该函数使用了平滑滤波算法，以保证输出的数据稳定，该算法不一定适用于所有情况，请更具实际情况选择对应的算法；
//==============================================================================================
unsigned short ADC_SampleFilter(void);

/*******************************************************************************
* Description    : 设置系统优先级总中断
* Input          : [INT_cfg]:
*                            H_SysPri_INIT_EN : 使能高优先级中断
*                            H_SysPri_INIT_Dis: 禁用高优先级中断
*                            L_SysPri_INIT_EN : 使能低优先级中断
*                            L_SysPri_INIT_Dis: 禁用低优先级中断
* Return         : None.
* Note           : None.
*******************************************************************************/
void System_INIT_Config(unsigned char INT_cfg);

#endif
