/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 202012001
* Description :
* Note		  : BUFFER UNIT输出1/4VDD到PC5,且当VCC低于3V3时产生LVD中断将PB3口拉低
********************************************************************************/

/********************************INCLUDES*************************************/
#include <math.h>
#include <stdio.h>
#include "AD18F02x.h"	//系统头文件
#include "CommDef.h"
#include "Common.h"
#include "Periph.h"
#include "usart.h"
/********************************配置字*************************************/
/***************************************************************************
*	常用配置字功能说明：
*
*	_FINTOSC_DIV1_1L：系统时钟选择--系统时钟不分频
*	_LVREN_ON_1L	: 掉电复位（Brown-out Reset）开关打开
*	_LVT24V_1L		：掉电复位电压选择 2.4v

*	_DBG_OFF_2L			: DEBUG 模式使能位， 使能后将固定 PA2 和 PA3 为 DEBUG IO
*	_FLASH_CP3_OFF_2L	：关闭0~1K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写
*	_FLASH_CP2_OFF_2L	：关闭1~2K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写
*	_FLASH_CP1_OFF_2L	: 关闭2~3K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写
*	_FLASH_CP0_OFF_2L	: 关闭3~4K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写

*	_CRYLEN_OFF_2L	: 禁止外部晶体低频振荡器
*	_CRYHEN_OFF_2L	：禁止外部晶体高频振荡器
*	_IDIS_OFF_2L	：关闭IO打开模拟功能时读取电平功能
*	_CKSUM_OFF_2L	: 关闭校验
*	_CBP_OFF_2L		: 代码不加密
*	_RESETE_OFF_2L	：复位脚禁止
*	_RSEL_LOW_2L	：端口上下拉选择30K
*	_STV_ON_2L		：堆栈溢出复位使能

*	_PSUT_1_3L		: 上电复位时间选择
*	_FCPU_4T_3L		: MCU选择4T模式
*	_WDTEN_OFF_3L	：WDT关闭
*	_TWDT_000_3L	：WDT溢出时间不分频

*	_OSCM_HIRC_16M_4L	：主时钟选择高速内部时钟---16MHz
*	_FCMEN_OFF_4L		: 禁止系统时钟失效监测，仅在系统时钟为外部晶振模式作用
*	_IESO_OFF_4L		：关闭双速启动模式， 仅在系统时钟为外部晶振模式才起作用
*	_ADCSP_ON_4L		: ADC 采集速度设置为高速

*	注意：1.配置字若无特别需求请勿修改；
*			2.其他配置字及相应功能见Datasheet及头文件；
*
****************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _LVREN_ON_1L      & _LVT24V_1L                                                                                             );
__CONFIG(2,_DBG_OFF_2L          & _FLASH_CP3_OFF_2L & _FLASH_CP2_OFF_2L & _FLASH_CP1_OFF_2L  &_FLASH_CP0_OFF_2L
		 &_CRYLEN_ON_2L         & _CRYHEN_ON_2L    & _IDIS_OFF_2L       & _CKSUM_ON_2L      & _CBP_OFF_2L     & _RESETE_OFF_2L & _RSEL_HIGH_2L  & _STV_ON_2L );
__CONFIG(3,_PSUT_32_3L           & _FCPU_2T_3L       & _WDTEN_OFF_3L     & _TWDT_011_3L                                                                       );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _FCMEN_OFF_4L     & _IESO_OFF_4L      & _ADCSP_ON_4L                                                                       );

/*******************************MACROS_USR************************************/
/********************************TYPEDEFS*************************************/
/********************************CONSTANTS************************************/
/****************************EXTERNAL FUNCTIONS*******************************/
/*****************************LOCAL FUNCTIONS*********************************/
/****************************EXTERNAL VARIABLES*******************************/
/******************************LOCAL VARIABLES********************************/
/*****************************GLOBAL VARIABLES********************************/
void main(void)
{
    PCON   = 0x30;     //先将LVD写入0x30
	PCON   = 0x19;     //设置LVD想要的功能，此处设置为VCC低于3.3V产生中断

	TRISC5 = 1;

	PC5PD  = 1;
	PC5PU  = 1;
	PC5OD  = 0;
	PC5AEN = 1;	       //使能PC5模拟功能
    BUCON  = 0x32;     //使能B_BUFF输出1/4VDD

	TRISB3 = 0;
	PB3    = 1;        //使能PC3输出高电平

	LVDIP  = 1;
	LVDIF  = 0;
	LVDIE  = 1;        //使能LVD高优先级中断

    IPEN   = 1;
    GIEL   = 1;
    GIEH   = 1;	       //使能总中断
	while(1);
}

//高优先级中断服务函数
void interrupt ISR_h (void)
{
	if(LVDIF == 1)
	{
		LVDIF = 0;     //清除中断标志
	    PB3   = 0;     //PB3输出低电平
	}
}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{

}
