/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数
********************************************************************************/

/********************************INCLUDES*************************************/
#include "Periph.h"


/*******************************************************************************
* Description    : BUF_Config
* Input          : ch:BUFFER输入通道选择;0-DAC0,1-DAC1,2-VDD/4,3-NTC,4-OP0,5-OP1,6-PA2,7-PA0
*				   OutEn:1-使能从PC5输出,0-禁止从IO输出
*				   mode-1~使能BUFFER，0~关闭BUFFER;
* Return         : None.
* Note           : None.
*******************************************************************************/

void BUF_Config(unsigned char ch,unsigned char OutEn,unsigned char mode)
{
	if(mode == 1)
	{
		BUCON = ch;			//输入通道选择
		BUCON |=1<<5;		//使能从PC5输出 1-输出使能
		BUCON |= 1<<4;		//buffer模块使能
	}
	else
	{
		BUCON &= ~(1<<4);		//关闭buffer模块
	}
}
/*******************************************************************************
* Description    : LVD_config
* Input          : 	Lvd_Mode：电压比较中断形式选择
								0:禁止电压比较器
								1:VCC低于阀值电压产生中断
								2:VCC高于阀值电压产生中断
								3:VCC高于阀值电压产生中断，且强制PB0输出PB0ST值
					Lvd_vol：VCC电压阈值选择
* Return         : None.
* Note           : None.
*******************************************************************************/
void LVD_config(unsigned char Lvd_Mode,unsigned char Lvd_vol)
{
	if(Lvd_Mode)
	{
		PCON = Lvd_Mode<< 4; 	//写入比较中断形式到PCON[5:4]
		PCON |= Lvd_vol;        //写入中断电压阀值

		LVDIP=1;
		LVDIF=0;
		LVDIE=1;				//开LVD中断
	}
	else
	{
		PCON&=0XCF;				//禁止电压比较器
		LVDIE=0;
	}
}

















