/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20210531
* Description : 1.CMP0正端输入PB0，负端0.5v,比较结果从PA2输出，软件中PB2随寄存器中
				CMP0OUT位输出而变化，中断设置为高优先级中断，发生中断后PB4翻转一次
				2.CMP1正端输入PA3，负端0.3v,比较结果从PA1输出，软件中PB3随寄存器中
				CMP1OUT位输出而变化，中断设置为低优先级中断，发生中断后PB5翻转一次
* Note        : None.
********************************************************************************/
#include "AD18F02x.h"
#include <stdio.h>
#include "common.h"
#include "Periph.h"
/*********************************************************************************************
* 常用配置字功能说明：
*
* _FINTOSC_DIV1_1L  :  内部时钟分频选择
* _LVREN_ON_1L      :  使能LVR
* _LVT24V_1L        ： 选择LVR电压为2.4V
* _DBG_OFF_2L       :  禁用DEBUG模式（使能后将固定PA2和PA3为DEBUG_IO）
* _FLASH_CP3_OFF_2L :  3K*16~4K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP2_OFF_2L ： 2K*16~3K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP1_OFF_2L ： 1K*16~2K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP0_OFF_2L ： 0k   ~1K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _CRYLEN_OFF_2L    ： 禁用外部低速时钟
* _CRYHEN_OFF_2L    ： 禁用外部高速时钟
* _IDIS_OFF_2L      ： 模拟IO打开，读取IO数据始终为0(模拟IO关闭，IDIS位对读取IO输入无影响)
* _CKSUM_OFF_2L     ： 使能程序校验
* _CBP_OFF_2L       :  禁用代码加密
* _RESETE_OFF_2L    ： 禁用外部复位
* _RSEL_LOW_2L      ： 端口上拉电阻为30KΩ，下拉电阻为30KΩ
* _STV_ON_2L        ： 使能堆溢出复位
* _PSUT_1_3L        ：  选择上电复位时间
* _FCPU_4T_3L       ： 选择指令周期为4T模式
* _WDTEN_OFF_3L     ： 使能看门狗
* _TWDT_000_3L      :  选择看门狗溢出时间，看门狗的延时时间要大于上电复位延时时间
* _OSCM_HIRC_16M_4L ： 选择内部高速时钟16MHz
* _FCMEN_OFF_4L     ： 系统时钟失效监测使能位
* _IESO_OFF_4L      ： 禁用双速启动模式（仅在系统时钟为外部晶振模式时有效）
* _ADCSP_ON_4L      ： 选择ADC采集为高速模式
*
* 注意：1.配置字若无特别需求请勿修改；
*       2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _LVREN_OFF_1L      & _LVT24V_1L                                                                                             );
__CONFIG(2,_DBG_OFF_2L          & _FLASH_CP3_OFF_2L & _FLASH_CP2_OFF_2L & _FLASH_CP1_OFF_2L  &_FLASH_CP0_OFF_2L
		&_CRYLEN_OFF_2L      & _CRYHEN_OFF_2L    & _IDIS_OFF_2L       & _CKSUM_OFF_2L      & _CBP_OFF_2L     & _RESETE_OFF_2L & _RSEL_LOW_2L & _STV_ON_2L  );
__CONFIG(3,_PSUT_32_3L           & _FCPU_4T_3L       & _WDTEN_OFF_3L     & _TWDT_011_3L                                                                       );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _FCMEN_OFF_4L     & _IESO_OFF_4L      & _ADCSP_ON_4L                                                                       );


void main (void)
{
	GPIO_Init();                           //所有IO初始化

	ANASEL1 = 0X01;                        //打开PB0模拟量
	TRISB0 = 1;                            //PB0_CMP0正端输入
	TRISA2 = 0;                            //PA2输出模式，CMP0输出IO

	ANASEL0 = 0X08;                        //打开PA3模拟量
	TRISA3 = 1;                            //PA3_CMP1正端输入
	TRISA1 = 0;                            //PA1输出模式,CMP1输出IO

//Cmp_p-CMP0正端输入通道选择，Cmp_p-CMP0负端输入通道选择；
//mode-1~使能CMP0，0~关闭CMP0;
	CMP0_Config(CMP0P_PB0,CMP0N_0V5,1);    //正端输入PB0，负端0.5v

//Cmp_p-CMP1正端输入通道选择，Cmp_p-CMP1负端输入通道选择；
//mode-1~使能CMP1，0~关闭CMP1;
	CMP1_Config(CMP1P_PA3,CMP1N_0V3,1);    //正端输入PA3，负端0.3v

//Cmp0-CMP0输出IO选择; 0~不输出,1~PA2,2~PB2,3~PA2/PB2同时输出
//Cmp1-CMP1输出IO选择; 0~不输出,1~PA1,2~PB2,3~PA1/PB2同时输出
	Cmpout_Config(1,1);                    //CMP0比较结果从PA2输出，CMP1比较结果从PA1输出

//CMP0中断设为高优先级
	CMP0IP=1;
	CMP0IF=0;
	CMP0IE=1;

//CMP0中断设为低优先级
	CMP1IP=0;
	CMP1IF=0;
	CMP1IE=1;
//使能中断优先级分级，打开中断使能
	IPEN=1;
	GIEH=1;
	GIEL=1;

	TRISB&=0XC3;	//PB2/3/4/5设置为输出
	while(1)
	{
		PB2=CMP0OUT;	//CMP0比较结果从PB2输出
		PB3=CMP1OUT;	//CMP1比较结果从PB3输出
	}
}


//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断
	if((CMP0IE==1)&&(CMP0IF==1))
	{
		CMP0IF=0;
		PB4=~PB4;
	}
}


//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//进入中断后系统自动关闭中断

	if((CMP1IE==1)&&(CMP1IF==1))
	{
		CMP1IF=0;
		PB5=~PB5;
	}
}


