/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数
********************************************************************************/

/********************************INCLUDES*************************************/
#include "Periph.h"

/*******************************************************************************
* Description    : CMP0_Config
* Input          : Cmp_p-CMP0正端输入通道选择，Cmp_p-CMP0负端输入通道选择；
*				   mode-1~使能CMP0，0~关闭CMP0;
* Return         : None.
* Note           : None.
*******************************************************************************/

void CMP0_Config(unsigned char Cmp_p,unsigned char Cmp_n,unsigned char mode)
{
	if(mode==1)
	{
		CMPCLKEN=1;             //时钟使能
		CMP0CON = Cmp_p << 2;  //正端输入选择
		CMP0CON |= Cmp_n;       //负端输入选择
		CMP0CON	|=1<<7;	        //使能CMP0
	}
	else
	{
		CMP0CON	&=~(1<<7);	//关闭CMP0
	}
}

/*******************************************************************************
* Description    : CMP1_Config
* Input          : Cmp_p-CMP1正端输入通道选择，Cmp_p-CMP1负端输入通道选择；
*				   mode-1~使能CMP1，0~关闭CMP1;
* Return         : None.
* Note           : None.
*******************************************************************************/
void CMP1_Config(unsigned char Cmp_p,unsigned char Cmp_n,unsigned char mode)
{
	if(mode==1)
	{
		CMPCLKEN=1;              //时钟使能
		CMP1CON = Cmp_p << 2;   //正端输入选择
		CMP1CON |= Cmp_n;       //负端输入选择
		CMP1CON	|=1<<7;	        //使能CMP0
	}
	else
	{
		CMP1CON	&=~(1<<7);	//关闭CMP0
	}
}

/*******************************************************************************
* Description    : CMP0_1输出IO选择
* Input          : Cmp0-CMP0输出IO选择; 0~不输出,1~PA2,2~PB2,3~PA2/PB2同时输出
*				   Cmp1-CMP1输出IO选择; 0~不输出,1~PA1,2~PB2,3~PA1/PB2同时输出
* Return         : None.
* Note           : None.
*******************************************************************************/

void Cmpout_Config(unsigned char Cmp0,unsigned char Cmp1)
{
	CMPCON=Cmp0;         //CMP0_OUT输出IO选择
	CMPCON|=Cmp1<<2;     //CMP1_OUT输出IO选择
}

