/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数
********************************************************************************/

/********************************INCLUDES*************************************/
#include "Periph.h"


/*******************************************************************************
* Description    : BUF_Config
* Input          : ch:BUFFER输入通道选择;0-DAC0,1-DAC1,2-VDD/4,3-NTC,4-OP0,5-OP1,6-PA2,7-PA0
*				   OutEn:1-使能从PC5输出,0-禁止从IO输出
*				   mode-1~使能BUFFER，0~关闭BUFFER;
* Return         : None.
* Note           : None.
*******************************************************************************/

void BUF_Config(unsigned char ch,unsigned char OutEn,unsigned char mode)
{
	if(mode == 1)
	{
		BUCON = ch;			//输入通道选择
		BUCON |=1<<5;		//使能从PC5输出 1-输出使能
		BUCON |= 1<<4;		//buffer模块使能
	}
	else
	{
		BUCON &= ~(1<<4);		//关闭buffer模块
	}
}



/*******************************************************************************
* Description    : DAC1_Config
* Input          : DacMode：DAC抽头选择
						0：Vdac = (n+9)*Vref/40, n = DAC[3:0] in decimal
						1：Vdac = (n+1)*Vref/32, n = DAC[3:0] in decimal
						2：Vdac = (n+9)*Vref/32, n = DAC[3:0] in decimal
						3：Vdac = (n+1)*Vref/24, n = DAC[3:0] in decimal
					Data：输出电压值选择，具体值根据上述公式计算
					state：1-使能DAC 0-关闭DAC
* Return         : None.
* Note           : None.
*******************************************************************************/
void DAC1_Config(unsigned char DacMode,unsigned char Data,unsigned char state)
{
	if(state == 1)
	{
		DACCON&=0x03;
		DACCON|=0x00;	//参考电压选择VDD,1-FVR,2-BUFFER_OUT
		DAC1CON = DacMode<<4;		//DAC工作模式选择
		DAC1CON |= Data;    		//DAC输出值选择
		DAC1CON |= 1<<6;     	//DAC使能
	}
	else
	{
		DAC1CON &= ~ (1<<6);     	//关闭DAC
	}
}


















