/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数
********************************************************************************/

/********************************INCLUDES*************************************/
#include "Periph.h"
#include "CommDef.h"


/*******************************************************************************
* Description    : 从FLASH中擦除ADDR所属页中的数据，每页256字节数据
* Input          : addr-待擦除的地址
* Return         : None.
* Note           : 需注意AD18F02x20无此功能
*******************************************************************************/
void FLASH_Erase(uint16_t addr)
{
	IAPWAIT = 0x23;
	IAPTRIG = 0xad;	//进入到 IAP mode
	IAPTRIG = 0x18;
	IAPTRIG = 0xf2;
	IAPADDRH = (unsigned char)(addr>>8);	//高8bit
	IAPADDRL = (unsigned char)(addr&0xff);	//低8bit
	IAPCTRL = 0X02;	//擦除FLASH
	IAPTRIG = 0X00;	//退出操作
}

/*******************************************************************************
* Description    : 向FLASH中写入数据
* Input          : addr-写入的地址；dat-待写入的数据
* Return         : None.
* Note           : 需注意AD18F02x20无此功能
*******************************************************************************/
static volatile  unsigned char  ALG8  @0XF04;
static volatile  unsigned char  ALG4  @0XF08;

void FLASH_WriteByte(uint16_t addr,uint16_t dat)
{
	unsigned char tmp;

	IAPWAIT  = 0x17;

	IAPTRIG  = 0xad;
	IAPTRIG  = 0x18;
	IAPTRIG  = 0xf2;

	IAPADDRH = (unsigned char)(addr>>8);	//高8bit
	IAPADDRL = (unsigned char)(addr&0xff);	//低8bit
	IAPDATL  = (unsigned char)(dat>>8);	    //高8bit
	IAPDATH  = (unsigned char)(dat&0xff);	//低8bit
	IAPCTRL = 0X01;	//写入FLASH

	tmp  = ALG8;
	ALG8 |= 0X80;
	ALG4 &= ~(1<<3);
	__delay_ms(5);      //延时时间必须保持，如果修改频率，请同步调整延时时间**********
	ALG4 |= (1<<3);
    ALG8 = tmp;

	IAPTRIG  = 0x00;
}



/*******************************************************************************
* Description    : 读取写入到FLASH中的数据
* Input          : None
* Return         : None.
* Note           : 需注意AD18F02x20无此功能
*******************************************************************************/
void Print_BUF(void)
{
    unsigned char a      = 0;
    unsigned int pr_temp = 0;

	printf("const unsigned char buf[256] @0x1800 ={");
    for(a = 0;a < 255; a++)
	{
		if(!(a%2))
		{
		    if(!(a%16))printf("\r\n");
			pr_temp = (unsigned int)(buf[a]<< 8);
			pr_temp = (unsigned int)(pr_temp|buf[a+1]);
			printf("0x%04X",pr_temp);
			if(a != 254)printf(", ");
		}
	}
	printf("\r\n};\r\n");
}

/*******************************************************************************
* Description    : 向FLASH中写入len字节数据
* Input          : addr-写入的地址；pbuf-待写入数据的指针；len-待写入的长度
* Return         : None.
* Note           : None.
*******************************************************************************/
void FLASH_WriteBuf(uint16_t addr, uint8_t *pbuf, uint8_t len)
{
	uint8_t i;
	uint8_t writelen;

	uint8_t datah;
	uint8_t datal;
	//FLASH的操作过程中必须关闭中断
	GIEL = 0;
	GIEH = 0;

	//擦除此后256字节（每次擦除必须为一整页）
	FLASH_Erase(addr);
	writelen = len/2;

	for (i = 0; i <writelen; i++)
	{
		datah = *pbuf++;
		datal = *pbuf++;
		FLASH_WriteByte(addr+(i*2),(datah<<8)+datal);
	}
	//FLASH的操作完成使能中断
	GIEL = 1;
	GIEH = 1;
}



