/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数头文件
********************************************************************************/


#ifndef __PERIPH_H__
#define __PERIPH_H__

#include <stdio.h>
#include "AD18F02x.h"
#include "Periph.h"
#include "Common.h"
#include "CommDef.h"

#define ADDR_FLASH 0X1800

extern const unsigned char buf[256] @ADDR_FLASH;


/*******************************************************************************
* Description    : 从FLASH中擦除ADDR所属页中的数据，每页256字节数据
* Input          : addr-待擦除的地址
* Return         : None.
* Note           : None.
*******************************************************************************/
void FLASH_Erase(uint16_t addr);

/*******************************************************************************
* Description    : 向Eeprom中写入数据
* Input          : addr-写入的地址；dat-待写入的数据
* Return         : None.
* Note           : None.
*******************************************************************************/
void FLASH_WriteByte(uint16_t addr,uint16_t dat);

/*******************************************************************************
* Description    : 读取写入到FLASH中的数据
* Input          : None
* Return         : None.
* Note           : 直接读取buf数组即可
*******************************************************************************/
void Print_BUF(void);

/*******************************************************************************
* Description    : 向FLASH中写入len字节数据
* Input          : addr-写入的地址；pbuf-待写入数据的指针；len-待写入的长度
* Return         : None.
* Note           : None.
*******************************************************************************/
void FLASH_WriteBuf(uint16_t addr, uint8_t *pbuf, uint8_t len);


#endif
