/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数
********************************************************************************/

/********************************INCLUDES*************************************/
#include "Periph.h"
#include "CommDef.h"

/*******************************************************************************
* Description    : 总中断使能，使能中断优先级
* Input          : None.
* Return         : None.
* Note           : None.
*******************************************************************************/

void Int_Enable()
{
	IPEN = 1;	   //使能中断优先级
	PEIE = 1;    // 外设GIEL
	GIE = 1;     // 全局GIEH
}


/*******************************************************************************
* Description    : 从FLASH中读出len字节数据写入指针中
* Input          : addr-读取数据的地址
* Return         : None.
* Note           : None.
*******************************************************************************/
void FLASH_Read(uint16_t addr,uint8_t *pbuf,uint8_t len)
{
   const unsigned char *ptr;
   ptr=(const unsigned char *)(addr);
   while(len--)
	  *pbuf++=*ptr++;
}


/*******************************************************************************
* Description    : 从FLASH中擦除ADDR所属页中的数据，每页128字节数据
* Input          : addr-待擦除的地址
* Return         : None.
* Note           : None.
*******************************************************************************/
void FLASH_Erase(uint16_t addr)
{
	IAPWAIT = 64; //16us; 16M/2T=8MHZ, 125nS * 16 = 16us
	IAPTRIG = 0xad;	//进入到 IAP mode
	IAPTRIG = 0x18;
	IAPTRIG = 0xf2;
	IAPADDRH = (unsigned char)(addr>>8);	//高5bit
	IAPADDRL = (unsigned char)(addr&0xff);	//低8bit
//	printf("erase FLASH from addr=0x%02x %02x\r\n",IAPADDRH,IAPADDRL);	//读取FLASH

	IAPCTRL = 0X02;	//擦除FLASH
	IAPTRIG = 0X00;	//退出操作
}

/*******************************************************************************
* Description    : 向FLASH中写入len字节数据写入指针中
* Input          : addr-写入的地址；pbuf-待写入数据的指针；len-待写入的长度
* Return         : None.
* Note           : None.
*******************************************************************************/
void FLASH_Write(uint16_t addr,uint8_t *pbuf,uint8_t len)
{
	uint8_t i;
	IAPWAIT = 64; //16us; 16M/2T=8MHZ, 125nS * 16 = 16us
	IAPTRIG = 0xad;	//进入到 IAP mode
	IAPTRIG = 0x18;
	IAPTRIG = 0xf2;

	for(i=0;i<len;)
	{
		IAPADDRH = (unsigned char)(addr>>8);	//高4bit
		IAPADDRL = (unsigned char)(addr&0xff);	//低8bit
		IAPDATL = pbuf[i++];
		if(i!=len)
		{
			IAPDATH = pbuf[i++];	//写入16bit数据高字节

		}
		else
			IAPDATH = 0xff;

		addr+=2;

		IAPCTRL = 0X01;	//写入FLASH
	}

// #if 0
	// for(i=0;i<len;i++)
	// {
		// IAPADDRH = (unsigned char)(addr>>8);	//高4bit
		// IAPADDRL = (unsigned char)(addr&0xfe);	//低8bit 地址只能写偶数

		// if(addr&0x01)
		// {
			// IAPDATH = pbuf[i];	//写入16bit数据高字节
			// IAPDATL = 0xff;
			// addr++;
		// }
		// else
		// {
			// IAPDATH = 0xff;	//写入16bit数据低字节
			// IAPDATL = pbuf[i];
			// addr++;
		// }
		// IAPCTRL = 0X01;	//写入FLASH
	// }
// #endif

	IAPTRIG = 0X00;	//退出操作
}
