/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20210531
* Description : PB4发生电平变化后产生中断，发生中断后PC3翻转1次
* Note        : None.
********************************************************************************/
#include "AD18F02x.h"
#include <stdio.h>
#include "common.h"
#include "Periph.h"
/*********************************************************************************************
* 常用配置字功能说明：
*
* _FINTOSC_DIV1_1L  :  内部时钟分频选择
* _LVREN_ON_1L      :  使能LVR
* _LVT24V_1L        ： 选择LVR电压为2.4V
* _DBG_OFF_2L       :  禁用DEBUG模式（使能后将固定PA2和PA3为DEBUG_IO）
* _FLASH_CP3_OFF_2L :  3K*16~4K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP2_OFF_2L ： 2K*16~3K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP1_OFF_2L ： 1K*16~2K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP0_OFF_2L ： 0k   ~1K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _CRYLEN_OFF_2L    ： 禁用外部低速时钟
* _CRYHEN_OFF_2L    ： 禁用外部高速时钟
* _IDIS_OFF_2L      ： 模拟IO打开，读取IO数据始终为0(模拟IO关闭，IDIS位对读取IO输入无影响)
* _CKSUM_OFF_2L     ： 使能程序校验
* _CBP_OFF_2L       :  禁用代码加密
* _RESETE_OFF_2L    ： 禁用外部复位
* _RSEL_LOW_2L      ： 端口上拉电阻为30KΩ，下拉电阻为30KΩ
* _STV_ON_2L        ： 使能堆溢出复位
* _PSUT_1_3L        ：  选择上电复位时间
* _FCPU_4T_3L       ： 选择指令周期为4T模式
* _WDTEN_OFF_3L     ： 使能看门狗
* _TWDT_000_3L      :  选择看门狗溢出时间，看门狗的延时时间要大于上电复位延时时间
* _OSCM_HIRC_16M_4L ： 选择内部高速时钟16MHz
* _FCMEN_OFF_4L     ： 系统时钟失效监测使能位
* _IESO_OFF_4L      ： 禁用双速启动模式（仅在系统时钟为外部晶振模式时有效）
* _ADCSP_ON_4L      ： 选择ADC采集为高速模式
*
* 注意：1.配置字若无特别需求请勿修改；
*       2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _LVREN_OFF_1L      & _LVT24V_1L                                                                                             );
__CONFIG(2,_DBG_OFF_2L          & _FLASH_CP3_OFF_2L & _FLASH_CP2_OFF_2L & _FLASH_CP1_OFF_2L  &_FLASH_CP0_OFF_2L
		&_CRYLEN_OFF_2L      & _CRYHEN_OFF_2L    & _IDIS_OFF_2L       & _CKSUM_OFF_2L      & _CBP_OFF_2L     & _RESETE_OFF_2L & _RSEL_LOW_2L & _STV_ON_2L  );
__CONFIG(3,_PSUT_32_3L           & _FCPU_4T_3L       & _WDTEN_OFF_3L     & _TWDT_011_3L                                                                       );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _FCMEN_OFF_4L     & _IESO_OFF_4L      & _ADCSP_ON_4L                                                                       );

volatile int flag,i;

void main (void)
{
	GPIO_Init();		//所有IO初始化
	TRISC3 = 0;			//PC3输出模式
//io：中断I/O通道选择（0~5）
//mode：选择是否开启I/O中断，1-打开中断，0-关闭中断
	PB_Int(4,1);		//选择PB4，允许PB4产生中断
	i=PINB;          	//锁存IO状态

	PBIF = 0;        	//清中断标志
	PBIE = 1;        	//PORTB中断使能
	PBIP = 1;			//高优先级中断

	IPEN = 1;        	//允许中断优先级
	PEIE = 1;        	//允许所有外设中断
	GIE  = 1;        	//开总中断

	while(1)
	{
		if(flag == 1)
		{
			flag = 0;
			PC3 =~PC3;
			i=PINB;          	//锁存IO状态   变量都PIN脚，可实现双沿触发，反之不读PIN脚则为下降沿触发
		}
	}
}

//高优先级中断服务函数

void interrupt ISR_h (void)
{
//进入中断后系统自动关闭中断
    unsigned char tmp_int;
	tmp_int=PIR2;
	if((PBIE == 1)&&((tmp_int&0X40)==0X40))
	{
		PBIF = 0;    //清标志位
		flag = 1;
	}
}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//进入中断后系统自动关闭中断
}


