/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数
********************************************************************************/

/********************************INCLUDES*************************************/
#include "Periph.h"

/*******************************************************************************
* Description    : OP0_Config
* Input          : 	P_ch：运放P端输入选择
						0-PC3
						1-FVROUT
						2-PC4
						3-OP1OUT
						4-BUOUT
						5-DAC0OUT
						6-DAC1OUT
						7-1.0V(BGR)
					N_ch：运放N端输入选择
						0-PA3
						1-FVROUT
						2-PA2
						3-DAC0OUT
					mode：1-使能运放，0-关闭运放
* Return         : None.
* Note           : 需注意AD18F02x22无此功能
*******************************************************************************/
void OP0_Config(unsigned char P_ch,unsigned char N_ch,unsigned char mode)
{
	if(mode == 1)
	{
		OP0_Offset_test();		//OP0的offset校准_BGR(1.0)校准
		OP0CON0 = 0X60;			//负端与NCH选择连接
		OP0CON0 |= P_ch<<2;		//运放P端输入选择
		OP0CON0 |= N_ch;		//运放N端输入选择

		OP0CON1 = 0X02;			//运放切换为比较器模式，不取反
		OP0CON2 = 0X84;       	//运放数字输出使能，滤波时间T=FILTER0[4:0] / Fcpu
		OP0CON0 |= 1<<7;		//使能运放
	}
	else
	{
		OP0CON0 &= ~(1<<7);		//关闭运放
	}
}

/*******************************************************************************
* Description    : OP1_Config
* Input          : 	P_ch：运放P端输入选择
						0-PC5
						1-FVROUT
						2-PB5
						3-OP0OUT
						4-BUOUT
						5-DAC0OUT
						6-DAC1OUT
						7-1.0V
					N_ch：运放N端输入选择
						0-PA0
						1-FVROUT
						2-PB0
						3-DAC1OUT
					mode：1-使能运放，0-关闭运放
* Return         : None.
* Note           : 需注意AD18F02x22无此功能
*******************************************************************************/
void OP1_Config(unsigned char P_ch,unsigned char N_ch,unsigned char mode)
{
	if(mode)
	{
		OP1_Offset_test();		//OP1的offset校准_BGR(1.0)校准
		OP1CON0 = 0X60;			//负端与NCH选择连接
		OP1CON0 |= P_ch<<2;		//运放P端输入选择
		OP1CON0 |= N_ch;		//运放N端输入选择

		OP1CON1 = 0X02;			//运放切换为比较器模式，不取反
		OP1CON2 = 0X84;       	//运放数字输出使能，滤波时间T=FILTER0[4:0] / Fcpu
		OP1CON0 |= 1<<7;		//使能运放
	}
	else
	{
		OP1CON0 &= ~(1<<7);		//关闭运放
	}
}
/*******************************************************************************
* Description	: OP0_Offset_test
* Input      	: None.
* Return        : None.
* Note          : 需注意AD18F02x22无此功能
*******************************************************************************/

void OP0_Offset_test(void)
{
	unsigned char VOOS1 = 0,start = 0;
	unsigned char i = 0;

	OPCON = 0X00;
	OP0CON0 = 0XDC;         //使能运放，关闭交换，正端输入1.0V
	OP0CON1 = 0X00;
	OP0CON2 = 0X04;         //模拟到数字信号使能
	OP0CON3 = 0X20;         //初始状态设置，校准使能

    __delay_us(300);
	start = OP0OUT;

	if(start == 1)
	{
		OP0CON3 |= 0X10;	//校准负值
	}
	else
	{
		OP0CON3 = 0X20;	    //校准正值
	}

	for(i=0;i<=15;i++)      //从0到15找翻转点
	{
		OP0_Offset(i);
		__delay_us(300);
		if(OP0OUT != start)
		{
			VOOS1 = i;
			break;
		}
	}
	OP0_Offset(15);         ////切换状态值并记录OP0OUT初始状态值
	__delay_us(300);
	start = OP0OUT;
	for(i=16;i>0;i--)       //从15到0找翻转点
	{
		OP0_Offset(i-1);
		__delay_us(300);
		if(OP0OUT != start)
		{
			VOOS1 =(VOOS1+ i-1)/2;
			break;
		}
	}
	OP0_OFFSETEN = 0;
	OP0_Offset(VOOS1);
}

/*******************************************************************************
* Description	: OP1_Offset_test
* Input      	: None.
* Return        : None.
* Note          :需注意AD18F02x22无此功能
*******************************************************************************/

void OP1_Offset_test(void)
{
	unsigned char VOOS1 = 0,start = 0;
	unsigned char i = 0;

	OPCON = 0X00;
	OP1CON0 = 0XDC;           //使能运放，关闭交换,正端输入1.0V
	OP1CON1 = 0X00;
	OP1CON2 = 0X04;           //模拟到数字信号使能
	OP1CON3 = 0X20;           //初始状态设置，校准使能

    __delay_us(300);
	start = OP1OUT;
	if(start == 1)
	{
		OP1CON3 |= 0X10;	//校准负值
	}
	else
	{
		OP1CON3 = 0X20;	    //校准正值
	}
	for(i=0;i<=15;i++)      //从0到15找翻转点
	{
		OP1_Offset(i);
		__delay_us(300);
		if(OP1OUT != start)
		{
			VOOS1 = i;
			break;
		}
	}

	OP1_Offset(15);        //切换状态值并记录OP1OUT初始状态值
	__delay_us(300);
	start = OP1OUT;
	for(i=16;i>0;i--)      //从15到0找翻转点
	{
		OP1_Offset(i-1);
		__delay_us(300);
		if(OP1OUT != start)
		{
			VOOS1 =(VOOS1 + i-1)/2;
			break;
		}
	}
	OP1_OFFSETEN = 0;     //关闭校准使能
	OP1_Offset(VOOS1);
}

/*******************************************************************************
* Description    : OP0_Offset
* Input          : 	Offset：校准值输入
* Return         : None.
* Note           :需注意AD18F02x22无此功能
*******************************************************************************/
void OP0_Offset(unsigned char Offset)
{
	OP0CON3=OP0CON3 & 0X30;
	OP0CON3 |= Offset;
}
/*******************************************************************************
* Description    : OP1_Offset
* Input          : 	Offset：校准值输入
* Return         : None.
* Note           : 需注意AD18F02x22无此功能
*******************************************************************************/
void OP1_Offset(unsigned char Offset)
{
	OP1CON3=OP1CON3 & 0X30;
	OP1CON3 |= Offset;
}

