/*******************************************************************************
* Device      : AD18F02x
* Author      :
* Version     : V0.0.1
* Date        : 20230522
* Description : 1、进入deeppwsave低功耗模式，并通过timer1计数溢出产生T1IF中断进行唤醒的功能。
*               进入deeppwsave低功耗模式之前，IO口PB2进行10次数翻转，进入deeppwsave模式睡眠后，IO口PB2停止翻转；
*				timer1计数溢出产生中断T1IF唤醒deeppwsave低功耗模式后，IO口PB2会再次进行翻转。
*               2、timer1产生中断PB3翻转
*
*					时钟--16MHz 波特率--19200  TX-PB0  RX-PB1
* NOTE		  :
********************************************************************************/

/********************************INCLUDES*************************************/
#include <stdio.h>
#include "AD18F02x.h"	//系统头文件
#include "CommDef.h"
#include "Common.h"
#include "Periph.h"
#include "usart.h"

/********************************配置字*************************************/
/***************************************************************************
*	常用配置字功能说明：
*
*	_FINTOSC_DIV1_1L：系统时钟选择--系统时钟不分频 /////
*	_LVREN_ON_1L	: 掉电复位（Brown-out Reset）开关打开
*	_LVT24V_1L		：掉电复位电压选择 2.4v

*	_DBG_OFF_2L			: DEBUG 模式使能位， 使能后将固定 PA2 和 PA3 为 DEBUG IO
*	_FLASH_CP3_OFF_2L	：关闭0~1K*16bit FLASH,(CBP 为 1 时有效)， 保护后不可擦写
*	_FLASH_CP2_OFF_2L	：关闭1~2K*16bit FLASH,(CBP 为 1 时有效)， 保护后不可擦写
*	_FLASH_CP1_OFF_2L	: 关闭2~3K*16bit FLASH,(CBP 为 1 时有效)， 保护后不可擦写
*	_FLASH_CP0_OFF_2L	: 关闭3~4K*16bit FLASH,(CBP 为 1 时有效)， 保护后不可擦写

*	_CRYLEN_OFF_2L	: 禁止外部晶体低频振荡器
*	_CRYHEN_OFF_2L	：禁止外部晶体高频振荡器
*	_IDIS_OFF_2L	：关闭IO打开模拟功能时读取电平功能
*	_CKSUM_OFF_2L	: 关闭校验
*	_CBP_OFF_2L		: 代码不加密
*	_RESETE_OFF_2L	：复位脚禁止
*	_RSEL_LOW_2L	：端口上下拉选择30K
*	_STV_ON_2L		：堆栈溢出复位使能

*	_PSUT_1_3L		: 上电复位时间选择
*	_FCPU_4T_3L		: MCU选择4T模式/////
*	_WDTEN_OFF_3L	：WDT关闭
*	_TWDT_000_3L	：WDT溢出时间不分频

*	_OSCM_HIRC_16M_4L	：主时钟选择高速内部时钟---16MHz /////
*	_FCMEN_OFF_4L		: 禁止系统时钟失效监测，仅在系统时钟为外部晶振模式作用
*	_IESO_OFF_4L		：关闭双速启动模式， 仅在系统时钟为外部晶振模式才起作用
*	_ADCSP_ON_4L		: ADC 采集速度设置为高速

*	注意：1.配置字若无特别需求请勿修改；
*			2.其他配置字及相应功能见Datasheet及头文件；
*          3.在进入睡眠之前，请将唤醒源再次配置使能
****************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _LVREN_OFF_1L      & _LVT24V_1L                                                                                             );
__CONFIG(2,_DBG_OFF_2L          & _FLASH_CP3_OFF_2L & _FLASH_CP2_OFF_2L & _FLASH_CP1_OFF_2L  &_FLASH_CP0_OFF_2L
           &_CRYLEN_OFF_2L      & _CRYHEN_OFF_2L    & _IDIS_OFF_2L       & _CKSUM_OFF_2L      & _CBP_OFF_2L     & _RESETE_OFF_2L & _RSEL_LOW_2L & _STV_ON_2L  );
__CONFIG(3,_PSUT_32_3L           & _FCPU_4T_3L       & _WDTEN_OFF_3L     & _TWDT_011_3L                                                                       );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _FCMEN_OFF_4L     & _IESO_OFF_4L      & _ADCSP_ON_4L                                                                       );

/*******************************MACROS_USR************************************/
/********************************TYPEDEFS*************************************/
/********************************CONSTANTS************************************/
/****************************EXTERNAL FUNCTIONS*******************************/
/*****************************LOCAL FUNCTIONS*********************************/
/****************************EXTERNAL VARIABLES*******************************/
/******************************LOCAL VARIABLES********************************/
/*****************************GLOBAL VARIABLES********************************/



void main(void)
{
	unsigned char i;

	TRISB2=0;       //PB2设为输出模式
	TRISB3=0;       //PB3设为输出模式

    T1CLKEN=1; 	    //使能tmr1时钟
	T1CON0=0X83;	//选择OSC32K做计数时钟，1分频，使能timer1;
	TMR1H=0XF9;	    //设置timer1的初值0xF900
	TMR1L=0X00;	    //


	IPEN=1;//允许高低优先级中断
	GIEH=1;//使能高优先级中断
	GIEL=1;//使能低优先级中断
    TMR1IP=1;//tmr1设为高优先级中断
    TMR1IF=0;//tmr1中断状态初始化为0
    TMR1IE=1;//使能tmr1中断允许位，才可进入中断服务函数

	while(1)
	{
		for(i=0;i<20;i++)
		{
			PB2=~PB2;
			__delay_us(100);
		}
		PB2=0;

		SLEEP_DEEPPWSAVE();//进入pwsave模式

	}
}


//中断服务函数
//高优先级中断服务函数
void __interrupt(high_priority) ISR_h(void)
{
	if((TMR1IE==1)&&(TMR1IF==1)&&(TMR1IP=1))
	{
		TMR1IF=0;
		PB3=~PB3; //用于检测定时器0的中断是否产生
	}
}
//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{

}

