#include "AD18F02x.h"
#include <stdio.h>

/*********************************************************************************************
* 常用配置字功能说明：
*
* _FINTOSC_DIV1_1L  :  内部时钟分频选择
* _LVREN_ON_1L      :  使能LVR
* _LVT24V_1L        ： 选择LVR电压为2.4V
* _DBG_OFF_2L       :  禁用DEBUG模式（使能后将固定PA2和PA3为DEBUG_IO）
* _FLASH_CP3_OFF_2L :  3K*16~4K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP2_OFF_2L ： 2K*16~3K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP1_OFF_2L ： 1K*16~2K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP0_OFF_2L ： 0k   ~1K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _CRYLEN_OFF_2L    ： 禁用外部低速时钟
* _CRYHEN_OFF_2L    ： 禁用外部高速时钟
* _IDIS_OFF_2L      ： 模拟IO打开，读取IO数据始终为0(模拟IO关闭，IDIS位对读取IO输入无影响)
* _CKSUM_OFF_2L     ： 使能程序校验
* _CBP_OFF_2L       :  禁用代码加密
* _RESETE_OFF_2L    ： 禁用外部复位
* _RSEL_LOW_2L      ： 端口上拉电阻为30KΩ，下拉电阻为30KΩ
* _STV_ON_2L        ： 使能堆溢出复位
* _PSUT_1_3L        ：  选择上电复位时间
* _FCPU_4T_3L       ： 选择指令周期为4T模式
* _WDTEN_OFF_3L     ： 使能看门狗
* _TWDT_000_3L      :  选择看门狗溢出时间，看门狗的延时时间要大于上电复位延时时间
* _OSCM_HIRC_16M_4L ： 选择内部高速时钟16MHz
* _FCMEN_OFF_4L     ： 系统时钟失效监测使能位
* _IESO_OFF_4L      ： 禁用双速启动模式（仅在系统时钟为外部晶振模式时有效）
* _ADCSP_ON_4L      ： 选择ADC采集为高速模式
*
* 注意：1.配置字若无特别需求请勿修改；
*       2.其他配置字及相应功能见Datasheet及头文件；
*
************************************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _LVREN_OFF_1L      & _LVT24V_1L                                                                                             );
__CONFIG(2,_DBG_OFF_2L          & _FLASH_CP3_OFF_2L & _FLASH_CP2_OFF_2L & _FLASH_CP1_OFF_2L  &_FLASH_CP0_OFF_2L
		&_CRYLEN_OFF_2L      & _CRYHEN_OFF_2L    & _IDIS_OFF_2L       & _CKSUM_OFF_2L      & _CBP_OFF_2L     & _RESETE_OFF_2L & _RSEL_LOW_2L & _STV_ON_2L  );
__CONFIG(3,_PSUT_32_3L           & _FCPU_4T_3L       & _WDTEN_OFF_3L     & _TWDT_011_3L                                                                       );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _FCMEN_OFF_4L     & _IESO_OFF_4L      & _ADCSP_ON_4L                                                                       );

//清SRAM
void sram_init()
{
    #asm
        INDF        EQU 0xFEF
        FSR0L       EQU 0xFE9
        FSR0H       EQU 0xFEA
        STATUS      EQU 0xfd8

        MOVLW 00h
        MOVWF FSR0L
    T0 :
        MOVLW 00H
        MOVWF INDF
        INCF  FSR0L
        MOVF  FSR0L,W
        XORLW 0x100
        BTFSS STATUS,2
        GOTO T0
        #endasm
}

void main(void)
{
    sram_init();

    while (1)
    {

    }

}
