#include "AD18F02x.h"
#include <stdio.h>
#include "common.h"

/*******************************************************************************
// ----Function: GPIO_Init
// --Parameters:
// -----Returns: None
//---------Note:所有IO初始化
*******************************************************************************/

void GPIO_Init(void)
{
	TRISA = 0X00;   //PA输出模式
	TRISB = 0X00;   //PB输出模式
	TRISC = 0X00;   //PC输出模式

	PORTA = 0X00;	//PORTA输出0
	PORTB = 0X00;	//PORTB输出0
	PORTC = 0X00;	//PORTC输出0

	PAPD = 0XFF;    //关闭PA下拉
	PAPU = 0XFF;    //关闭PA上拉
	PBPD = 0XFF;    //关闭PB下拉
	PBPU = 0XFF;    //关闭PB上拉
	PCPD = 0XFF;    //关闭PC下拉
	PCPU = 0XFF;    //关闭PC上拉

	PAOD = 0X00;    //关PA开漏输出
	PBOD = 0X00;    //关PB开漏输出
	PCOD = 0X00;    //关PC开漏输出

	ANASEL0 = 0X00; //关PA模拟量通道
	ANASEL1 = 0X00; //关PB模拟量通道
	ANASEL2 = 0X00; //关PC模拟量通道
}

/*******************************************************************************
// ----Function: Timer1_Init
// --Parameters:
// -----Returns: None
//---------Note: 定时器1初始化
			Fcpu作为TMR1时钟:
			4T	t = (FFFF-TMR)*定时器1分频系数*4T/16MHz
			2T	t = (FFFF-TMR)*定时器1分频系数*2T/16MHz
			其它时钟源作为TMR1时钟:
			t = (FFFF-TMR)*定时器1分频系数/osc
*******************************************************************************/

void timer1_Init(void)
{
	T1CLKEN = 1;     //开T1时钟
	CCPCLKEN = 1;	//开CCP时钟
	CCPCON  = 0x07;  //比较模式，选择CCPR1 匹配时将产生软件中断,并触发AD(ADON = 1)
	CCPR1H  = 0x9C;
	CCPR1L  = 0x3F; //初值40000
	TMR1H   = 0x00;
	TMR1L   = 0x00; //初值设置0,t = 40000*8(分频)*4T/16MHz = 80ms
	T1CON0  = 0x31; //使能Timer1,选择FCPU时钟外设作为TIMER1的时钟,8分频
   	CCPIF = 0;
	CCPIE = 1;
	CCPIP = 1;		//高优先级中断

	IPEN = 0;       //允许中断优先级
	PEIE = 1;       //允许所有外设中断
}

/*******************************************************************************
// ----Function: AD_init
// --Parameters:
// -----Returns: None
//---------Note: AD模块初始化设置，采集输入通道为PA3
*******************************************************************************/

void AD_init()
{
	ADCON1 = 0X7E;        //VDD作为参考电压，采集时间15TAD，采集时钟FSYS/64
	ADCON0 = 0X01;        //AD转换结果右对齐，PA3输入，使能AD模块
	ADIF   = 0;           //清AD中断标志
	ADIE   = 1;           //开AD中断
	ADIP   = 1;           //高优先级中断

	IPEN = 0;             //允许中断优先级
	PEIE = 1;             //允许所有外设中断
}




