/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20210531
* Description : TIMER1的捕获模式，捕获通道为PA0,捕获数据通过串口输出。同时CCP
				每产生一次中断，PB2翻转一次
* Note		  :	串口TX-PB0，RX-PB1，波特率-19200
********************************************************************************/

#include "AD18F02x.h"
#include <stdio.h>
#include "common.h"
#include "usart.h"

/******************************************************************************
* 常用配置字功能说明：
*
* _FINTOSC_DIV1_1L  :  内部时钟分频选择
* _LVREN_ON_1L      :  使能LVR
* _LVT24V_1L        ： 选择LVR电压为2.4V
* _DBG_OFF_2L       :  禁用DEBUG模式（使能后将固定PA2和PA3为DEBUG_IO）
* _FLASH_CP3_OFF_2L :  3K*16~4K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP2_OFF_2L ： 2K*16~3K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP1_OFF_2L ： 1K*16~2K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _FLASH_CP0_OFF_2L ： 0k   ~1K*16 FLASH保护位，保护后不可擦写(仅CBP为1时有效)
* _CRYLEN_OFF_2L    ： 禁用外部低速时钟
* _CRYHEN_OFF_2L    ： 禁用外部高速时钟
* _IDIS_OFF_2L      ： 模拟IO打开，读取IO数据始终为0(模拟IO关闭，IDIS位对读取IO输入无影响)
* _CKSUM_OFF_2L     ： 使能程序校验
* _CBP_OFF_2L       :  禁用代码加密
* _RESETE_OFF_2L    ： 禁用外部复位
* _RSEL_LOW_2L      ： 端口上拉电阻为30KΩ，下拉电阻为30KΩ
* _STV_ON_2L        ： 使能堆栈溢出复位
* _PSUT_1_3L        ：  选择上电复位时间
* _FCPU_4T_3L       ： 选择指令周期为4T模式
* _WDTEN_OFF_3L     ： 使能看门狗
* _TWDT_000_3L      :  选择看门狗溢出时间，看门狗的延时时间要大于上电复位延时时间
* _OSCM_HIRC_16M_4L ： 选择内部高速时钟16MHz
* _FCMEN_OFF_4L     ： 系统时钟失效监测使能位
* _IESO_OFF_4L      ： 禁用双速启动模式（仅在系统时钟为外部晶振模式时有效）
* _ADCSP_ON_4L      ： 选择ADC采集为高速模式
*
* 注意：1.配置字若无特别需求请勿修改；
*       2.其他配置字及相应功能见Datasheet及头文件；
*
******************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _LVREN_OFF_1L      & _LVT24V_1L                                                                                             );
__CONFIG(2,_DBG_OFF_2L          & _FLASH_CP3_OFF_2L & _FLASH_CP2_OFF_2L & _FLASH_CP1_OFF_2L  &_FLASH_CP0_OFF_2L
		&_CRYLEN_OFF_2L      & _CRYHEN_OFF_2L    & _IDIS_OFF_2L       & _CKSUM_OFF_2L      & _CBP_OFF_2L     & _RESETE_OFF_2L & _RSEL_LOW_2L & _STV_ON_2L  );
__CONFIG(3,_PSUT_32_3L           & _FCPU_4T_3L       & _WDTEN_OFF_3L     & _TWDT_011_3L                                                                       );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _FCMEN_OFF_4L     & _IESO_OFF_4L      & _ADCSP_ON_4L                                                                       );


unsigned char CCPFlag = 0;
unsigned int CCP_Data = 0;

void main (void)
{
	GPIO_Init();
	TRISA0 = 1;     //CCPCH0_PA0输入模式
	TRISB2 = 0;		//PB2输出模式

	Usart();
// --Parameters: channel:捕获通道选择
			   //mode:捕获模式选择
	Timer1_Caputure_Init(CAPTURE_CH0,CAPTURE_MODE0);//捕获通道为PA0，模式:下降沿捕获，产生中断标志
    printf("18F02 TIMER1 CCP CAPTURE DEMO!\r\n");
	GIE = 1;
    while(1)
    {
	   if(CCPFlag == 1)
	   {
			CCPFlag = 0;
			CCP_Data = (CCPR1H<<8 | CCPR1L);
			printf("CCP_Data = %u us \r\n",CCP_Data);    //打印捕获数据
			TMR1H = 0X00;
			TMR1L = 0X00;
			CCPIE = 1;
			GIE = 1;
	   }
    }
}

//高优先级中断服务函数
void interrupt ISR_h(void)
{
	//进入中断后系统自动关闭中断
   if(CCPIE == 1 && CCPIF == 1)
   {
	  CCPIF = 0;
	  CCPIE = 0;
	  GIE = 0;
	  CCPFlag = 1;
	  PB2 =~ PB2;
   }
}
//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{
//进入中断后系统自动关闭中断
}
