#include "AD18F02x.h"
#include <stdio.h>
#include "common.h"

/*******************************************************************************
// ----Function: GPIO_Init
// --Parameters:
// -----Returns: None
//---------Note:所有IO初始化
*******************************************************************************/

void GPIO_Init(void)
{
	TRISA = 0X00;   //PA输出模式
	TRISB = 0X00;   //PB输出模式
	TRISC = 0X00;   //PC输出模式

	PORTA = 0X00;	//PORTA输出0
	PORTB = 0X00;	//PORTB输出0
	PORTC = 0X00;	//PORTC输出0

	PAPD = 0XFF;    //关闭PA下拉
	PAPU = 0XFF;    //关闭PA上拉
	PBPD = 0XFF;    //关闭PB下拉
	PBPU = 0XFF;    //关闭PB上拉
	PCPD = 0XFF;    //关闭PC下拉
	PCPU = 0XFF;    //关闭PC上拉

	PAOD = 0X00;    //关PA开漏输出
	PBOD = 0X00;    //关PB开漏输出
	PCOD = 0X00;    //关PC开漏输出

	ANASEL0 = 0X00; //关PA模拟量通道
	ANASEL1 = 0X00; //关PB模拟量通道
	ANASEL2 = 0X00; //关PC模拟量通道
}

/*******************************************************************************
* Description    : 总中断使能，使能中断优先级
* Input          : None.
* Return         : None.
* Note           : None.
*******************************************************************************/

void Int_Enable()
{
	IPEN = 0;	   	//禁止中断优先级
	PEIE = 1;    	//外设GIEL
	GIE = 1;     	//全局GIEH
}

/*******************************************************************************
// ----Function:TIMER1_EDGE_Measure
// --Parameters:mode:测量模式选择
				T1edge:选择计数方式
				channel:输入通道选择
// -----Returns:None.
//---------Note:None.
*******************************************************************************/
void TIMER1_EDGE_Measure(uint8_t mode,uint8_t T1edge,uint8_t channel)
{
   //对应GPIO设置为输入的模式，关闭上下拉，关闭开漏，关闭模拟通道
   switch(channel)
   {
	  case  CHANNEL_PA0:{TRISA0 = 1;PA0PD = 1;PA0PU = 1;PA0OD = 0;PA0AEN = 0;}break;
	  case  CHANNEL_PA4:{TRISA4 = 1;PA4PD = 1;PA4PU = 1;PA4OD = 0;PA4AEN = 0;}break;
	  case  CHANNEL_PA5:{TRISA5 = 1;PA5PD = 1;PA5PU = 1;PA5OD = 0;PA4AEN = 0;}break;
	  default: break;
   }
   T1CLKEN = 1;    		  //开T1时钟
   TMR1H  = 0X00;
   TMR1L  = 0X00;         //清0

   T1CON1 = 0X00;
   T1EDGE = T1edge;       //选择上升沿开始计数或下降沿开始计数
   T1CON1 |= channel << 2;//选择测量通道
   T1CON1 |= mode;        //选择脉宽测量模式
   T1CON0 = 0X21;         //T1时钟源为系统时钟16M，4T，4分频，使能T1，每记一个数1us

   printf("\r\n/*** [DEBUG] ***/\r\n");
   printf("T1CON0 = 0X%02X !\r\n",T1CON0);
   printf("T1CON1 = 0X%02X !\r\n",T1CON1);
   printf("/***************/\r\n\r\n");

   TMR1IF = 0;     //清中断标志
   TMR1IE = 1;     //开TMR1中断
   TMR1IP = 1;     //高优先级中断
}




