#include "AD18F02x.h"
#include <stdio.h>
#include "common.h"

/*******************************************************************************
// ----Function: GPIO_Init
// --Parameters:
// -----Returns: None
//---------Note:所有IO初始化
*******************************************************************************/

void GPIO_Init(void)
{
	TRISA = 0X00;   //PA输出模式
	TRISB = 0X00;   //PB输出模式
	TRISC = 0X00;   //PC输出模式

	PORTA = 0X00;	//PORTA输出0
	PORTB = 0X00;	//PORTB输出0
	PORTC = 0X00;	//PORTC输出0

	PAPD = 0XFF;    //关闭PA下拉
	PAPU = 0XFF;    //关闭PA上拉
	PBPD = 0XFF;    //关闭PB下拉
	PBPU = 0XFF;    //关闭PB上拉
	PCPD = 0XFF;    //关闭PC下拉
	PCPU = 0XFF;    //关闭PC上拉

	PAOD = 0X00;    //关PA开漏输出
	PBOD = 0X00;    //关PB开漏输出
	PCOD = 0X00;    //关PC开漏输出

	ANASEL0 = 0X00; //关PA模拟量通道
	ANASEL1 = 0X00; //关PB模拟量通道
	ANASEL2 = 0X00; //关PC模拟量通道
}

/*******************************************************************************
* Description    : 总中断使能，使能中断优先级
* Input          : None.
* Return         : None.
* Note           : None.
*******************************************************************************/

void Int_Enable()
{
	IPEN = 0;	   	//禁止中断优先级
	PEIE = 1;    	//外设GIEL
	GIE = 1;     	//全局GIEH
}
/*******************************************************************************
// ----Function: Timer1_Init
// --Parameters:
// -----Returns: None
//---------Note: 定时器1初始化，定时10ms
			Fcpu作为TMR1时钟:
			4T	t = (FFFF-TMR)*定时器1分频系数*4T/16MHz
			2T	t = (FFFF-TMR)*定时器1分频系数*2T/16MHz
			其它时钟源作为TMR1时钟:
			t = (FFFF-TMR)*定时器1分频系数/osc
*******************************************************************************/

void timer1_Init(void)
{
	T1CLKEN = 1;    //开T1时钟
	TMR1H = 0XF9;   //t = (65536-63936)*1/32KHz = 50ms
	TMR1L = 0XC0;
	T1CON1 = 0X03;  //工作在定时模式，定时触发AD转换
	T1CON0 = 0X83;  //TMR1时钟为内部时钟32KHz，使能TMR1时钟，不分频
}

/*******************************************************************************
// ----Function: AD_init
// --Parameters:
// -----Returns: None
//---------Note: AD模块初始化设置，采集输入通道为PA3
*******************************************************************************/

void AD_init()
{
	ADCCLKEN = 1;		  //开ADC时钟
	ADCON1 = 0X7E;        //VDD作为参考电压，采集时间15TAD，采集时钟FSYS/64
	ADCON2 = 0X03;        //使能自动采集,使能FVR启动
	ADCON0 = 0X01;        //AD转换结果右对齐，PA3输入，使能AD模块

	ADIF   = 0;           //清AD中断标志
	ADIE   = 1;           //开AD中断
	ADIP   = 1;           //高优先级中断
}
