/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 串口驱动
********************************************************************************/


#include "AD18F02x.h"
#include <stdio.h>
#include "usart.h"

/*******************************************************************************
* Description    : 初始化串口
* Input          : None.
* Return         : None.
* Note           : None.
*******************************************************************************/

void Com_Init()
{
    UARTCLKEN = 1;

	UARTCON=0x00;
	RX_PIN = 1;
	TX_PIN = 0;
	SPBRG=DIVIDER;	//波特率
	RCSTA = (NINE_BITS|0x90);			//使能串口，八位接收，使能接收 第九位接收设为0
	TXSTA = (SPEED|NINE_BITS|0x20);	//八位发送 使能发送 异步模式  BGRH 选择高速  第九位发送设为0
#if UART_SW == 1
	UART_MUX=1; //切换IO 至 B0/1
#endif

}

/*******************************************************************************
* Description    : 单线串口发送初始化
* Input          : None.
* Return         : None.
* Note           : None.
*******************************************************************************/

void Com_TxInit()
{
    UARTCLKEN = 1;

 	TX_RX_PIN=0;

	UARTCON=0x08;
	SPBRG=DIVIDER;	//波特率
	RCSTA = (NINE_BITS|0x80);			//使能串口，八位接收，禁止接收 第九位接收设为0
	TXSTA = (SPEED|NINE_BITS|0x20);	//八位发送 使能发送 异步模式  BGRH 选择高速  第九位发送设为0
#if UART_SW == 1
	UART_MUX=1; //切换IO 至 B0/1
#endif

}

/*******************************************************************************
* Description    : 单线串口接收初始化
* Input          : None.
* Return         : None.
* Note           : None.
*******************************************************************************/

void Com_RxInit()
{
    UARTCLKEN = 1;

 	TX_RX_PIN=1;

	UARTCON=0x08;
	SPBRG=DIVIDER;	//波特率
	RCSTA = (NINE_BITS|0x90);			//使能串口，八位接收，使能接收 第九位接收设为0
	TXSTA = (SPEED|NINE_BITS|0x00);	//八位发送 禁止发送 异步模式  BGRH 选择高速  第九位发送设为0
#if UART_SW == 1
	UART_MUX=1; //切换IO 至 B0/1
#endif

}


/*******************************************************************************
* Description    : 打印单个字符
* Input          : 待打印字符.
* Return         : None.
* Note           : None.
*******************************************************************************/
//printf函数重定向
void putch(unsigned char byte)
{
	/* output one byte */
	while(!TXIF)	/* set when register is empty */
		continue;
	TXREG = byte;
	while(!TXIF);
	while(!TRMT);
}

/*******************************************************************************
* Description    : 接收打印单个字符
* Input          : None.
* Return         : 接收到的字符.
* Note           : None.
*******************************************************************************/

unsigned char getch()
{
	/* retrieve one byte */
	while(!RCIF)	/* set when register is not empty */
		continue;
	return RCREG;
}

/*******************************************************************************
* Description    : 接收打印单个字符
* Input          : None.
* Return         : 接收到的字符.
* Note           : None.
*******************************************************************************/

unsigned char getche(void)
{
	unsigned char c;
	putch(c = getch());
	return c;
}
