/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 202012001
* Description :
* Note		  : 该例程测试看门狗复位时间，在配置字中开启看门狗并设置复位时间为128ms，上电后PC2口输出一段方波信号，进入while后PC2口输出低电平；
*               可在PC3和PC4口接入一个按键（按下为0），当按键全部按下时，执行喂狗,此时芯片不产生复位，PC2口一直输出低电平;
*               当按键没有按下，此时不执行喂狗指令，PC2口保存一段时间低电平后芯片复位，复位时PC2口再次输出一段方波信号，若一直没有喂狗，则将一直在PC2口输出该方波信号;
********************************************************************************/

/********************************INCLUDES*************************************/

#include <math.h>
#include <stdio.h>
#include "AD18F02x.h"	//系统头文件
#include "CommDef.h"
#include "Common.h"
#include "Periph.h"
#include "usart.h"

/********************************配置字*************************************/
/***************************************************************************
*	常用配置字功能说明：
*
*	_FINTOSC_DIV1_1L：系统时钟选择--系统时钟不分频
*	_LVREN_ON_1L	: 掉电复位（Brown-out Reset）开关打开
*	_LVT24V_1L		：掉电复位电压选择 2.4v

*	_DBG_OFF_2L			: DEBUG 模式使能位， 使能后将固定 PA2 和 PA3 为 DEBUG IO
*	_FLASH_CP3_OFF_2L	：关闭0~1K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写
*	_FLASH_CP2_OFF_2L	：关闭1~2K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写
*	_FLASH_CP1_OFF_2L	: 关闭2~3K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写
*	_FLASH_CP0_OFF_2L	: 关闭3~4K*16bit FLASH,(CBP 为 1 时有效)， !!!保护后不可擦写

*	_CRYLEN_OFF_2L	: 禁止外部晶体低频振荡器
*	_CRYHEN_OFF_2L	：禁止外部晶体高频振荡器
*	_IDIS_OFF_2L	：关闭IO打开模拟功能时读取电平功能
*	_CKSUM_OFF_2L	: 关闭校验
*	_CBP_OFF_2L		: 代码不加密
*	_RESETE_OFF_2L	：复位脚禁止
*	_RSEL_LOW_2L	：端口上下拉选择30K
*	_STV_ON_2L		：堆栈溢出复位使能

*	_PSUT_1_3L		: 上电复位时间选择
*	_FCPU_4T_3L		: MCU选择4T模式
*	_WDTEN_OFF_3L	：WDT关闭
*	_TWDT_000_3L	：WDT溢出时间不分频

*	_OSCM_HIRC_16M_4L	：主时钟选择高速内部时钟---16MHz
*	_FCMEN_OFF_4L		: 禁止系统时钟失效监测，仅在系统时钟为外部晶振模式作用
*	_IESO_OFF_4L		：关闭双速启动模式， 仅在系统时钟为外部晶振模式才起作用
*	_ADCSP_ON_4L		: ADC 采集速度设置为高速

*	注意：1.配置字若无特别需求请勿修改；
*			2.其他配置字及相应功能见Datasheet及头文件；
*
****************************************************************************/

__CONFIG(1,_FINTOSC_DIV1_1L     & _LVREN_OFF_1L      & _LVT24V_1L                                                                                                 );
__CONFIG(2,_DBG_OFF_2L          & _FLASH_CP3_OFF_2L & _FLASH_CP2_OFF_2L & _FLASH_CP1_OFF_2L  &_FLASH_CP0_OFF_2L
		  &_CRYLEN_OFF_2L       & _CRYHEN_OFF_2L    & _IDIS_OFF_2L      & _CKSUM_OFF_2L      & _CBP_OFF_2L       & _RESETE_OFF_2L  & _RSEL_LOW_2L  & _STV_ON_2L  );
__CONFIG(3,_PSUT_32_3L           & _FCPU_2T_3L       & _WDTEN_ON_3L     & _TWDT_011_3L                                                                           );
__CONFIG(4,_OSCM_HIRC_16M_4L    & _FCMEN_OFF_4L     & _IESO_OFF_4L      & _ADCSP_ON_4L                                                                           );

/*******************************MACROS_USR************************************/
/********************************TYPEDEFS*************************************/
/********************************CONSTANTS************************************/
/****************************EXTERNAL FUNCTIONS*******************************/
/*****************************LOCAL FUNCTIONS*********************************/
/****************************EXTERNAL VARIABLES*******************************/
/******************************LOCAL VARIABLES********************************/
/*****************************GLOBAL VARIABLES********************************/

void main(void)
{
	unsigned char i;
        TRISC2 = 0;              //PC2为输出模式
    PC2    = 1;              //PC2输出高电平
	GPIO_Init();             //初始化GPIO

    TRISC2 = 0;              //PC2为输出模式
    PC2    = 1;              //PC2输出高电平

    TRISC3 = 1;              //PC3为输入模式
    PC3PU  = 0;              //PC3开启内部上拉

    TRISC4 = 1;              //PC4为输入模式
    PC4PU  = 0;              //PC4开启内部上拉

    for(i = 0;i<128;i++)
    {
	   PC2 = ~PC2;
    }

    while(1)
    {
	    PC2   = 0;   //PC2口输出低电平
        if(PINC3 == 0  && PINC4 == 0)
	    {
           CLRWDT(); //喂狗
	    }
    }
}

//高优先级中断服务函数
void interrupt ISR_h (void)
{

}

//低优先级中断服务函数
void interrupt low_priority ISR_l (void)
{

}
