/*******************************************************************************
* Device      : AD18F02x
* Author      : XAD Application Team
* Version     : V0.0.1
* Date        : 20201201
* Description : 系统外设驱动函数
********************************************************************************/

/********************************INCLUDES*************************************/
#include <stdio.h>
#include "Periph.h"
#include "CommDef.h"

volatile unsigned char temp_s0     = 0;
volatile unsigned char temp_s1     = 0;
volatile unsigned char temp_s2     = 0;
volatile unsigned char ADON2_1     = 0;
volatile unsigned char ADON2_2     = 0;

/*******************************************************************************
* Description    : TIMER2初始化设置
* Input          : [T2_YF]:
*				    Y_FOSC_1 : TIMER2预分频为1
*				    Y_FOSC_4 : TIMER2预分频为4
*		  	        Y_FOSC_8 : TIMER2预分频为8
*				    Y_FOSC_16: TIMER2预分频为16
*
*				   [PWM_Freq]:0-65535 单位KHz
*                   !PWM周期 = FOSC/[PR2H:PR2L]/Timer2预分频值/Timer2后分频值
*
*                  [T2_HF]:
*				    H_FOSC_1 : TIMER2后分频为1
*				    H_FOSC_2 : TIMER2后分频为2
*			 	    H_FOSC_3 : TIMER2后分频为3
*			  	    H_FOSC_4 : TIMER2后分频为4
*				    H_FOSC_5 : TIMER2后分频为5
*				    H_FOSC_6 : TIMER2后分频为6
*				    H_FOSC_7 : TIMER2后分频为7
*				    H_FOSC_8 : TIMER2后分频为8
*				    H_FOSC_9 : TIMER2后分频为9
*				    H_FOSC_10: TIMER2后分频为10
*				    H_FOSC_11: TIMER2后分频为11
*				    H_FOSC_12: TIMER2后分频为12
*				    H_FOSC_13: TIMER2后分频为13
*				    H_FOSC_14: TIMER2后分频为14
*				    H_FOSC_15: TIMER2后分频为15
*				    H_FOSC_16: TIMER2后分频为16
*
*                  [T2_ON]:
*				    Timer2_ENABLE : 使能TIMER2
*				    Timer2_DISABLE: 禁用TIMER2
*
*                  [Pri_INT]:
*				    INT_OFF  : 禁用TIMER2中断
*				    H_Pri_INT: 使能TIMER2高优先级中断:
*				    L_Pri_INT: 使能TIMER2低优先级中断
*
* Return         : None.
* Note           : None.
*******************************************************************************/
void Timer2_Init(unsigned char T2_YF,unsigned long PWM_Freq,unsigned char T2_HF,unsigned char T2_ON,unsigned char Pri_INT)
{
	unsigned char Temp   = 0;
	unsigned char Temp_F = 0;
	unsigned long Dat1   = 0;
         if(T2_YF == Y_FOSC_1) Temp_F = 1;
	else if(T2_YF == Y_FOSC_4) Temp_F = 4;
	else if(T2_YF == Y_FOSC_8) Temp_F = 8;
	else if(T2_YF == Y_FOSC_16)Temp_F = 16;

    //清空TMR2
	TMR2H  = 0x00;
	TMR2L  = 0x00;

	//设置预分频
    if(T2_YF > H_FOSC_1 && T2_YF <= H_FOSC_16)
	{
         Temp = Temp|(T2_YF<<0);
	}else
	{
	     Temp = Temp|(0x00<<0);
	}

	//设置后分频
    if(T2_HF > Y_FOSC_1 && T2_HF <= Y_FOSC_16)
    {
         Temp = Temp|(T2_HF<<3);
     }else
	{
		 Temp = Temp|(0x00<<3);
	 }

	//启动或者关闭TIMER2
	if(T2_ON <= Timer2_ENABLE && T2_ON > Timer2_DISABLE )Temp = Temp|(T2_ON<<2);else Temp = T2CON|(0<<2);

#ifdef CCP_PWM
	if(CCP_PWM == TRUE)
	{
		//设置周期
		if(PWM_Freq <= 65535 && PWM_Freq > 0 )
		{
		   Dat1 = 16000000/PWM_Freq;
		   PR2H = (Dat1>> 8) & 0xFF;
		   PR2L = Dat1 & 0xFF;
		}else
		{
		   PR2H = 0x06;PR2L = 0x40;
		}
	}else if(CCP_PWM == FALSE)
	{
		//定时时间
		if(PWM_Freq <= 65535 && PWM_Freq > 0 )
		{
		   Dat1 = 16000000/Temp_F/PWM_Freq/(T2_HF+1);
		   PR2H = (Dat1>> 8) & 0xFF;
		   PR2L = Dat1 & 0xFF;
		}else
		{
		   PR2H = 0x03;PR2L = 0xE0;
		}
	}
#else
	//定时时间
	if(PWM_Freq <= 65535 && PWM_Freq >= 0 )
	{
		Dat1 = 16000000/Temp_F/PWM_Freq/(T2_HF+1);
		PR2H = (Dat1>> 8) & 0xFF;
		PR2L = Dat1 & 0xFF;
	}else
	{
		PR2H = 0x03;PR2L = 0xE0;
	}
#endif

    T2CON = Temp;
    printf("/**********TIMER2*********/\r\n");
	Temp = 0;Temp = PR2L;
	printf("PR2L     = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = PR2H;
	printf("PR2H     = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = TMR2L;
	printf("TMR2L    = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = TMR2H;
	printf("TMR2H    = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = T2CON;
	printf("T2CON    = 0x%02X; \r\n",Temp);
	Temp = 0;

	//TIMER2中断设置
	     if(Pri_INT == H_Pri_INT){TMR2IF = 0;TMR2IP = 1;TMR2IE = 1;printf("TMR2IF   = 0;\r\nTMR2IP   = 1;\r\nTMR2IE   = 1;\r\n");}
	else if(Pri_INT == L_Pri_INT){TMR2IF = 0;TMR2IP = 0;TMR2IE = 1;printf("TMR2IF   = 0;\r\nTMR2IP   = 0;\r\nTMR2IE   = 1;\r\n");}
	else {TMR2IF = 0;TMR2IP = 1;TMR2IE = 0;printf("TMR2IF   = 0;\r\nTMR2IP   = 1;\r\nTMR2IE   = 0;\r\n");}

	printf("/**********TIMER2*********/\r\n");
}

/*******************************************************************************
* Description    : TIMER3初始化设置
* Input          : [T3_YF]:
*				    Y_FOSC_1 : TIMER3预分频为1
*				    Y_FOSC_4 : TIMER3预分频为4
*		  	        Y_FOSC_8 : TIMER3预分频为8
*				    Y_FOSC_16: TIMER3预分频为16
*
*				   [PWM_Freq]:0-65535 单位KHz
*                   !PWM周期 = FOSC/[PR2H:PR2L]/Timer2预分频值/Timer2后分频值
*
*                  [T3_HF]:
*				    H_FOSC_1 : TIMER3后分频为1
*				    H_FOSC_2 : TIMER3后分频为2
*			 	    H_FOSC_3 : TIMER3后分频为3
*			  	    H_FOSC_4 : TIMER3后分频为4
*				    H_FOSC_5 : TIMER3后分频为5
*				    H_FOSC_6 : TIMER3后分频为6
*				    H_FOSC_7 : TIMER3后分频为7
*				    H_FOSC_8 : TIMER3后分频为8
*				    H_FOSC_9 : TIMER3后分频为9
*				    H_FOSC_10: TIMER3后分频为10
*				    H_FOSC_11: TIMER3后分频为11
*				    H_FOSC_12: TIMER3后分频为12
*				    H_FOSC_13: TIMER3后分频为13
*				    H_FOSC_14: TIMER3后分频为14
*				    H_FOSC_15: TIMER3后分频为15
*				    H_FOSC_16: TIMER3后分频为16
*
*                  [T3_ON]:
*				    Timer3_ENABLE : 使能TIMER3
*				    Timer3_DISABLE: 禁用TIMER3
*
*                  [Pri_INT]:
*				    INT_OFF  : 禁用TIMER3中断
*				    H_Pri_INT: 使能TIMER3高优先级中断:
*				    L_Pri_INT: 使能TIMER3低优先级中断
*
* Return         : None.
* Note           : None.
*******************************************************************************/
void Timer3_Init(unsigned char T3_YF,unsigned long PWM_Freq,unsigned char T3_HF,unsigned char T3_ON,unsigned char Pri_INT)
{
	unsigned char Temp   = 0;
	unsigned char Temp_F = 0;
	unsigned long Dat1   = 0;
         if(T3_YF == Y_FOSC_1) Temp_F = 1;
	else if(T3_YF == Y_FOSC_4) Temp_F = 4;
	else if(T3_YF == Y_FOSC_8) Temp_F = 8;
	else if(T3_YF == Y_FOSC_16)Temp_F = 16;

    //清空TMR2
	TMR3H  = 0x00;
	TMR3L  = 0x00;

	//设置预分频
    if(T3_YF > H_FOSC_1 && T3_YF <= H_FOSC_16)
	{
         Temp = Temp|(T3_YF<<0);
	}else
	{
	     Temp = Temp|(0x00<<0);
	}

	//设置后分频
    if(T3_HF > Y_FOSC_1 && T3_HF <= Y_FOSC_16)
    {
         Temp = Temp|(T3_HF<<3);
     }else
	{
		 Temp = Temp|(0x00<<3);
	 }

	//启动或者关闭TIMER2
	if(T3_ON <= Timer3_ENABLE && T3_ON > Timer3_DISABLE )Temp = Temp|(T3_ON<<2);else Temp = T3CON|(0<<2);

#ifdef CCP_PWM
	if(CCP_PWM == TRUE)
	{
		//设置周期
		if(PWM_Freq <= 65535 && PWM_Freq > 0 )
		{
		   Dat1 = 16000000/PWM_Freq;
		   PR3H = (Dat1>> 8) & 0xFF;
		   PR3L = Dat1 & 0xFF;
		}else
		{
		   PR3H = 0x06;PR3L = 0x40;
		}
	}else if(CCP_PWM == FALSE)
	{
		//定时时间
		if(PWM_Freq <= 65535 && PWM_Freq > 0 )
		{
		   Dat1 = 16000000/Temp_F/PWM_Freq/(T3_HF+1);
		   PR3H = (Dat1>> 8) & 0xFF;
		   PR3L = Dat1 & 0xFF;
		}else
		{
		   PR3H = 0x03;PR3L = 0xE0;
		}
	}
#else
	//定时时间
	if(PWM_Freq <= 65535 && PWM_Freq >= 0 )
	{
		Dat1 = 16000000/Temp_F/PWM_Freq/(T3_HF+1);
		PR3H = (Dat1>> 8) & 0xFF;
		PR3L = Dat1 & 0xFF;
	}else
	{
        PR3H = 0x03;PR3L = 0xE0;
	}
#endif

    T3CON = Temp;
    printf("/**********TIMER3*********/\r\n");
	Temp = 0;Temp = PR3L;
	printf("PR3L     = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = PR3H;
	printf("PR3H     = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = TMR3L;
	printf("TMR3L    = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = TMR3H;
	printf("TMR3H    = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = T3CON;
	printf("T3CON    = 0x%02X; \r\n",Temp);
	Temp = 0;

	//TIMER2中断设置
	     if(Pri_INT == H_Pri_INT){TMR3IF = 0;TMR3IP = 1;TMR3IE = 1;printf("TMR3IF   = 0;\r\nTMR3IP   = 1;\r\nTMR3IE   = 1;\r\n");}
	else if(Pri_INT == L_Pri_INT){TMR3IF = 0;TMR3IP = 0;TMR3IE = 1;printf("TMR3IF   = 0;\r\nTMR3IP   = 0;\r\nTMR3IE   = 1;\r\n");}
	else {TMR3IF = 0;TMR3IP = 1;TMR3IE = 0;printf("TMR3IF   = 0;\r\nTMR3IP   = 1;\r\nTMR3IE   = 0;\r\n");}

	printf("/**********TIMER3*********/\r\n");
}


/*******************************************************************************
* Description    : CCP_PWM10—PWM15初始化
* Input          : None.
* Return         : None.
* Note           : 需转到periph.文件"PWM10_PWM15宏定义设置"区对需要的功能进行设
*                  置，然后在执行该初始化程序
*                  PWM10_PC5、PWM12_PB4、PWM14_PB2/PC2
*                  PWM11_PB5、PWM13_PB3、PWM15_PC4

*                  PWM10_PC5、PWM12_PB4、PWM14_PB2/PB2
*                  PWM11_PB5、PWM13_PB3、PWM15_PC4
*******************************************************************************/
void CCP_PWM_Init(void)
{
	unsigned char Temp = 0;

	CCPR1LH= 0x00;
	CCPR1L = 0x00;

	#ifdef DEBUG_P
    printf("/******************/\r\n");
	#endif
#ifdef PWM10_11_MODE
 		 if(PWM10_11_MODE == PWM_CPMT){PMS0_1 = 0;PMS0_0 = 0;
	#ifdef DEBUG_P
	printf("PMS0_1    = 0;\r\nPMS0_0    = 0;\r\n");
	#endif
	PXC0_1 = 0;PXC0_0 = 0;}
	else if(PWM10_11_MODE == UP_ARM  ){PMS0_1 = 0;PMS0_0 = 1;
	#ifdef DEBUG_P
	printf("PMS0_1    = 0;\r\nPMS0_0    = 1;\r\n");
	#endif
	PXC0_1 = 0;PXC0_0 = 0;}
	else if(PWM10_11_MODE == DW_ARM  ){PMS0_1 = 1;PMS0_0 = 0;
	#ifdef DEBUG_P
	printf("PMS0_1    = 1;\r\nPMS0_0    = 0;\r\n");
	#endif
	PXC0_1 = 0;PXC0_0 = 0;}
	else if(PWM10_11_MODE == SEL_cfg )
    {
	    #ifdef DEBUG_P
		PMS0_1 = 1;PMS0_0 = 1;printf("PMS0_1    = 1;\r\nPMS0_0    = 1;\r\n");
		#endif
	#ifdef PWM10_11_SEL
			 if(PWM10_11_SEL == SEL_UP_DW_OFF   ){PXC0_1 = 0;PXC0_0 = 0;
		#ifdef DEBUG_P
		printf("PXC0_1    = 0;\r\nPXC0_0    = 0;\r\n");
		#endif
		}
		else if(PWM10_11_SEL == SEL_UP_OFF_DW_ON){PXC0_1 = 0;PXC0_0 = 1;
		#ifdef DEBUG_P
		printf("PXC0_1    = 0;\r\nPXC0_0    = 1;\r\n");
		#endif
		}
		else if(PWM10_11_SEL == SEL_UP_ON_DW_OFF){PXC0_1 = 1;PXC0_0 = 0;
		#ifdef DEBUG_P
		printf("PXC0_1    = 1;\r\nPXC0_0    = 0;\r\n");
		#endif
		}
		else if(PWM10_11_SEL == SEL_UPDW_Mw_OFF ){PXC0_1 = 1;PXC0_0 = 1;
		#ifdef DEBUG_P
		printf("PXC0_1    = 1;\r\nPXC0_0    = 1;\r\n");
		#endif
		}
	#else
		PXC0_1 = 0;PXC0_0 = 0;
		#ifdef DEBUG_P
		printf("PXC0_1    = 0;\r\nPXC0_0    = 0;\r\n");
		#endif
	#endif
	}
#else
    PMS0_1 = 0;PMS0_0 = 0;
	#ifdef DEBUG_P
    printf("PMS0_1    = 0;\r\nPMS0_0    = 0;\r\n");
	#endif
#endif

#ifdef PWM12_13_MODE
 		 if(PWM12_13_MODE == PWM_CPMT){PMS1_1 = 0;PMS1_0 = 0;
	#ifdef DEBUG_P
	printf("PMS1_1    = 0;\r\nPMS1_0    = 0;\r\n");
	#endif
	PXC1_1 = 0;PXC1_0 = 0;}
	else if(PWM12_13_MODE == UP_ARM  ){PMS1_1 = 0;PMS1_0 = 1;
	#ifdef DEBUG_P
	printf("PMS1_1    = 0;\r\nPMS1_0    = 1;\r\n");
	#endif
	PXC1_1 = 0;PXC1_0 = 0;}
	else if(PWM12_13_MODE == DW_ARM  ){PMS1_1 = 1;PMS1_0 = 0;
	#ifdef DEBUG_P
	printf("PMS1_1    = 1;\r\nPMS1_0    = 0;\r\n");
	#endif
	PXC1_1 = 0;PXC1_0 = 0;}
	else if(PWM12_13_MODE == SEL_cfg )
    {
	    #ifdef DEBUG_P
		PMS1_1 = 1;PMS1_0 = 1;printf("PMS1_1    = 1;\r\nPMS1_0    = 1;\r\n");
		#endif
	#ifdef PWM12_13_SEL
			 if(PWM12_13_SEL == SEL_UP_DW_OFF   ){PXC1_1 = 0;PXC1_0 = 0;
		#ifdef DEBUG_P
		printf("PXC1_1    = 0;\r\nPXC1_0    = 0;\r\n");
		#endif
		}
		else if(PWM12_13_SEL == SEL_UP_OFF_DW_ON){PXC1_1 = 0;PXC1_0 = 1;
		#ifdef DEBUG_P
		printf("PXC1_1    = 0;\r\nPXC1_0    = 1;\r\n");
		#endif
		}
		else if(PWM12_13_SEL == SEL_UP_ON_DW_OFF){PXC1_1 = 1;PXC1_0 = 0;
		#ifdef DEBUG_P
		printf("PXC1_1    = 1;\r\nPXC1_0    = 0;\r\n");
		#endif
		}
		else if(PWM12_13_SEL == SEL_UPDW_Mw_OFF ){PXC1_1 = 1;PXC1_0 = 1;
		#ifdef DEBUG_P
		printf("PXC1_1    = 1;\r\nPXC1_0    = 1;\r\n");
		#endif
		}
	#else
		PXC1_1 = 0;PXC1_0 = 0;
		#ifdef DEBUG_P
		printf("PXC1_1    = 0;\r\nPXC1_0    = 0;\r\n");
		#endif
	#endif
	}
#else
    PMS1_1 = 0;PMS1_0 = 0;
	#ifdef DEBUG_P
    printf("PMS1_1    = 0;\r\nPMS1_0    = 0;\r\n");
	#endif
#endif

#ifdef PWM14_15_MODE
 		 if(PWM14_15_MODE == PWM_CPMT){PMS2_1 = 0;PMS2_0 = 0;
	#ifdef DEBUG_P
	printf("PMS2_1    = 0;\r\nPMS2_0    = 0;\r\n");
	#endif
	PXC2_1 = 0;PXC2_0 = 0;}
	else if(PWM14_15_MODE == UP_ARM  ){PMS2_1 = 0;PMS2_0 = 1;
	#ifdef DEBUG_P
	printf("PMS2_1    = 0;\r\nPMS2_0    = 1;\r\n");
	#endif
	PXC2_1 = 0;PXC2_0 = 0;}
	else if(PWM14_15_MODE == DW_ARM  ){PMS2_1 = 1;PMS2_0 = 0;
	#ifdef DEBUG_P
	printf("PMS2_1    = 1;\r\nPMS2_0    = 0;\r\n");
	#endif
	PXC2_1 = 0;PXC2_0 = 0;}
	else if(PWM14_15_MODE == SEL_cfg )
    {
		PMS2_1 = 1;PMS2_0 = 1;
		#ifdef DEBUG_P
		printf("PMS2_1    = 1;\r\nPMS2_0    = 1;\r\n");
		#endif
	#ifdef PWM14_15_SEL
			 if(PWM14_15_SEL == SEL_UP_DW_OFF   ){PXC2_1 = 0;PXC2_0 = 0;
		#ifdef DEBUG_P
		printf("PXC2_1    = 0;\r\nPXC2_0    = 0;\r\n");
		#endif
		}
		else if(PWM14_15_SEL == SEL_UP_OFF_DW_ON){
		#ifdef DEBUG_P
		PXC2_1 = 0;PXC2_0 = 1;printf("PXC2_1    = 0;\r\nPXC2_0    = 1;\r\n");
		#endif
		}
		else if(PWM14_15_SEL == SEL_UP_ON_DW_OFF){PXC2_1 = 1;PXC2_0 = 0;
		#ifdef DEBUG_P
		printf("PXC2_1    = 1;\r\nPXC2_0    = 0;\r\n");
		#endif
		}
		else if(PWM14_15_SEL == SEL_UPDW_Mw_OFF ){PXC2_1 = 1;PXC2_0 = 1;
		#ifdef DEBUG_P
		printf("PXC2_1    = 1;\r\nPXC2_0    = 1;\r\n");
		#endif
		}
	#else
		PXC2_1 = 0;PXC2_0 = 0;
		#ifdef DEBUG_P
		printf("PXC2_1    = 0;\r\nPXC2_0    = 0;\r\n");
		#endif
	#endif
	}
#else
    PMS2_1 = 0;PMS2_0 = 0;
	#ifdef DEBUG_P
	printf("PMS2_1    = 0;\r\nPMS2_0    = 0;\r\n");
	#endif
#endif

#ifdef DTE_cfg
	#ifdef DT_Fosc
		 if(DT_Fosc == FDT_Fsys  ){DTCKS1 = 0;DTCKS0 = 0;
	#ifdef DEBUG_P
	printf("DTCKS1   = 0;\r\nDTCKS0   = 0;\r\n");
	#endif
	}
	else if(DT_Fosc == FDT_Fsys_2){DTCKS1 = 0;DTCKS0 = 1;
	#ifdef DEBUG_P
	printf("DTCKS1   = 0;\r\nDTCKS0   = 1;\r\n");
	#endif
	}
	else if(DT_Fosc == FDT_Fsys_4){DTCKS1 = 1;DTCKS0 = 0;
	#ifdef DEBUG_P
	printf("DTCKS1   = 1;\r\nDTCKS0   = 0;\r\n");
	#endif
	}
	else if(DT_Fosc == FDT_Fsys_8){DTCKS1 = 1;DTCKS0 = 1;
	#ifdef DEBUG_P
	printf("DTCKS1   = 1;\r\nDTCKS0   = 1;\r\n");
	#endif
	}
	#else
		DTCKS1 = 0;
		DTCKS0 = 0;
		#ifdef DEBUG_P
		printf("DTCKS1   = 0;\r\nDTCKS0   = 0;\r\n");
		#endif
	#endif
	#ifdef DTD_cfg
	    if(DTD_cfg <= 31 || DTD_cfg > 0)
		{
		if((DTD_cfg >> 4) & 1)DTD4 = 1;else DTD4 = 0;
		if((DTD_cfg >> 3) & 1)DTD3 = 1;else DTD3 = 0;
		if((DTD_cfg >> 2) & 1)DTD2 = 1;else DTD2 = 0;
		if((DTD_cfg >> 1) & 1)DTD1 = 1;else DTD1 = 0;
		if((DTD_cfg >> 0) & 1)DTD0 = 1;else DTD0 = 0;
		#ifdef DEBUG_P
        printf("DTD4     = %d;\r\nDTD3     = %d;\r\nDTD2     = %d;\r\nDTD1     = %d;\r\nDTD0     = %d;\r\n",DTD4,DTD3,DTD2,DTD1,DTD0);
		#endif
		}else
        {
			DTD4 = 1;
			DTD3 = 0;
			DTD2 = 0;
			DTD1 = 0;
			DTD0 = 0;
			#ifdef DEBUG_P
			printf("DTD4     = 1;\r\nDTD3     = 0;\r\nDTD2     = 0;\r\nDTD1     = 0;\r\nDTD0     = 0;\r\n");
			#endif
        }
	#else
		DTD4 = 0;
		DTD3 = 0;
		DTD2 = 0;
		DTD1 = 0;
		DTD0 = 0;
		#ifdef DEBUG_P
	    printf("DTD4     = 0;\r\nDTD3     = 0;\r\nDTD2     = 0;\r\nDTD1     = 0;\r\nDTD0     = 0;\r\n");
		#endif
	#endif
    DTEN = DTE_cfg;
	#ifdef DEBUG_P
    printf("DTEN     = %d;\r\n",DTE_cfg);
	#endif
#else
    DTEN = 0;
	#ifdef DEBUG_P
	printf("DTEN     = 0;\r\n");
	#endif
#endif

#ifdef DMISTK2_FC
    DMISTK2 = DMISTK2_FC;
	#ifdef DEBUG_P
    printf("DMISTK2  = %d;\r\n",DMISTK2_FC);
	#endif
	#ifdef DMISTK2_FC
		PWMH = DMISTK2_OUT;
		#ifdef DEBUG_P
	    printf("PWMH     = %d;\r\n",DMISTK2_OUT);
		#endif
	#else
		PWMH = 0;
		#ifdef DEBUG_P
		printf("PWMH     = 0;\r\n");
		#endif
	#endif
#else
    DMISTK2 = 0;
	#ifdef DEBUG_P
	printf("DMISTK2  = 0;\r\n");
	#endif
#endif

#ifdef Failure_Stop
    ALOSE = Failure_Stop;
	#ifdef DEBUG_P
    printf("ALOSE    = %d;\r\n",Failure_Stop);
	#endif
#else
    ALOSE = 0;
	#ifdef DEBUG_P
	printf("ALOSE    = 0;\r\n");
	#endif
#endif

#ifdef Relieve_Renew
    ASTART = Relieve_Renew;
	#ifdef DEBUG_P
	printf("ASTART   = %d;\r\n",Relieve_Renew);
	#endif
#else
    ASTART = 0;
	#ifdef DEBUG_P
	printf("ASTART   = 0;\r\n");
	#endif
#endif

#ifdef CMPOUT_Protect
    CMPFLT = CMPOUT_Protect;
	#ifdef DEBUG_P
	printf("CMPFLT   = %d;\r\n",CMPOUT_Protect);
	#endif
#else
    CMPFLT = 0;
	#ifdef DEBUG_P
	printf("IOFLT    = 0;\r\n");
	#endif
#endif

#ifdef OPOUT_Protect
    OPFLT = OPOUT_Protect;
	#ifdef DEBUG_P
	printf("OPFLT    = %d;\r\n",OPOUT_Protect);
	#endif
#else
    OPFLT = 0;
	#ifdef DEBUG_P
	printf("IOFLT    = 0;\r\n");
	#endif
#endif

#ifdef IO_PC2_Protect
    IOFLT = IO_PC2_Protect;
	#ifdef DEBUG_P
	printf("IOFLT    = %d;\r\n",IO_PC2_Protect);
	#endif
#else
    IOFLT = 0;
	#ifdef DEBUG_P
	printf("IOFLT    = 0;\r\n");
	#endif
#endif

#ifdef PT11_OUT
    PT0MODE = PT11_OUT;
	#ifdef DEBUG_P
	printf("PT0MODE  = %d;\r\n",PT11_OUT);
	#endif
#else
    PT0MODE = 0;
	#ifdef DEBUG_P
	printf("PT2MODE  = 0;\r\n");
	#endif
#endif

#ifdef PT13_OUT
    PT1MODE = PT13_OUT;
	#ifdef DEBUG_P
	printf("PT1MODE  = %d;\r\n",PT13_OUT);
	#endif
#else
    PT1MODE = 0;
	#ifdef DEBUG_P
	printf("PT2MODE  = 0;\r\n");
	#endif
#endif

#ifdef PT15_OUT
    PT2MODE = PT15_OUT;
	#ifdef DEBUG_P
	printf("PT2MODE  = %d;\r\n",PT15_OUT);
	#endif
#else
    PT2MODE = 0;
	#ifdef DEBUG_P
	printf("PT2MODE  = 0;\r\n");
	#endif
#endif

#ifdef PWM10_POLS
    POLS10 = PWM10_POLS;
	#ifdef DEBUG_P
    printf("POLS10   = %d;\r\n",PWM10_POLS);
	#endif
#else
    POLS10 = 0;
	#ifdef DEBUG_P
	printf("POLS10   = 0;\r\n");
	#endif
#endif

#ifdef PWM11_POLS
    POLS11 = PWM11_POLS;
	#ifdef DEBUG_P
    printf("POLS11   = %d;\r\n",PWM11_POLS);
	#endif
#else
    POLS11 = 0;
	#ifdef DEBUG_P
	printf("POLS11   = 0;\r\n");
	#endif
#endif

#ifdef PWM12_POLS
    POLS12 = PWM12_POLS;
	#ifdef DEBUG_P
    printf("POLS12   = %d;\r\n",PWM12_POLS);
	#endif
#else
    POLS12 = 0;
	#ifdef DEBUG_P
	printf("POLS12   = 0;\r\n");
	#endif
#endif

#ifdef PWM13_POLS
    POLS13 = PWM13_POLS;
	#ifdef DEBUG_P
    printf("POLS13   = %d;\r\n",PWM13_POLS);
	#endif
#else
    POLS13 = 0;
	#ifdef DEBUG_P
	printf("POLS13   = 0;\r\n");
	#endif
#endif

#ifdef PWM14_POLS
    POLS14 = PWM14_POLS;
	#ifdef DEBUG_P
    printf("POLS14   = %d;\r\n",PWM14_POLS);
	#endif
#else
    POLS14 = 0;
	#ifdef DEBUG_P
	printf("POLS14   = 0;\r\n");
	#endif
#endif

#ifdef PWM15_POLS
    POLS15 = PWM15_POLS;
	#ifdef DEBUG_P
    printf("POLS15   = %d;\r\n",PWM15_POLS);
	#endif
#else
    POLS15 = 0;
	#ifdef DEBUG_P
	printf("POLS15   = 0;\r\n");
	#endif
#endif

#ifdef CCP_PWM10
    PWM0EN0 = CCP_PWM10;
	TRISC5     = 0;
	#ifdef DEBUG_P
    printf("PWM0EN0  = %d;\r\n",CCP_PWM10);
    printf("TRISC5   = 0;\r\n");
	#endif
#else
	PWM0EN0 = 0;
	#ifdef DEBUG_P
	printf("PWM0EN0  = 0;\r\n");
	#endif
#endif

#ifdef CCP_PWM11
    PWM0EN1 = CCP_PWM11;
	TRISB5     = 0;
	#ifdef DEBUG_P
    printf("PWM0EN1  = %d;\r\n",CCP_PWM11);
    printf("TRISB5   = 0;\r\n");
	#endif
#else
	PWM0EN1 = 0;
	#ifdef DEBUG_P
	printf("PWM0EN1  = 0;\r\n");
	#endif
#endif

#ifdef CCP_PWM12
    PWM1EN0 = CCP_PWM12;
	#ifdef DEBUG_P
    printf("PWM1EN0  = %d;\r\n",CCP_PWM12);
	#endif

#else
	PWM1EN0 = 0;
	#ifdef DEBUG_P
	printf("PWM1EN0  = 0;\r\n");
	#endif
#endif





#ifdef CCP_PWM12
	PWM1EN0  = 1;
	TRISB4   = 0;
	#ifdef DEBUG_P
    printf("PWM1EN0  = %d;\r\nTRISB4   = 0;\r\n",CCP_PWM13);
	#endif
#else
	PWM1EN0 = 0;
	#ifdef DEBUG_P
	printf("PWM1EN0  = 0;\r\n");
	#endif
#endif

#ifdef CCP_PWM13
    PWM1EN1 = CCP_PWM13;
	TRISB3  = 0;
	#ifdef DEBUG_P
    printf("PWM1EN1  = %d;\r\nTRISB3   = 0;\r\n",CCP_PWM13);
	#endif
#else
	PWM1EN1 = 0;
	#ifdef DEBUG_P
	printf("PWM1EN1  = 0;\r\n");
	#endif
#endif

#ifdef CCP_PWM14
    PWM2EN0 = CCP_PWM14;
	TRISB2  = 0;
	#ifdef DEBUG_P
    printf("PWM2EN0  = %d;\r\nTRISB2   = 0;\r\n",CCP_PWM14);
	#endif


	#ifdef PWM14_IO_CFG
		 if(PWM14_IO_CFG == PC2_OUT){PWM14SEL = 1;TRISC2= 0;
		 #ifdef DEBUG_P
		 printf("PWM14SEL = 1;\r\nTRISC2   = 0;\r\n");
		 #endif
		 }
	else if(PWM14_IO_CFG == PB2_OUT){PWM14SEL = 0;TRISB2 = 0;
	#ifdef DEBUG_P
	printf("PWM14SEL = 0;\r\nTRISB2   = 0;\r\n");
	#endif
	}
	else {PWM14SEL = 0;TRISB2 = 0;
	#ifdef DEBUG_P
	printf("PWM14SEL = 0;\r\nTRISB2   = 0;\r\n");
	#endif
	}
	#else
        PWM2EN0  = 1;
		PWM14SEL = 0;
		TRISB2   = 0;
		#ifdef DEBUG_P
        printf("PWM2EN0   = 1;\r\nPWM14SEL  = 0;\r\nTRISB2   = 0;\r\n");
		#endif
	#endif


#else
	PWM2EN0 = 0;
	#ifdef DEBUG_P
	printf("PWM2EN0  = 0;\r\n");
	#endif
#endif

#ifdef CCP_PWM15
    PWM2EN1 = CCP_PWM15;
	TRISC4  = 0;
	#ifdef DEBUG_P
    printf("PWM2EN1  = %d;\r\nTRISC4   = 0;\r\n",CCP_PWM15);
	#endif
#else
	PWM2EN1 = 0;
	#ifdef DEBUG_P
	printf("PWM2EN1  = 0;\r\n");
	#endif
#endif

#ifdef TIME3_PWM
    T3PWMEN = TIME3_PWM;
	#ifdef DEBUG_P
    printf("T3PWMEN  = %d;\r\n",TIME3_PWM);
	#endif
#else
    T3PWMEN = 0;
	#ifdef DEBUG_P
	printf("T3PWMEN  = 0;\r\n");
	#endif
#endif

#ifdef PWM10_EDGE_ADC
    PWM10ADEN  = PWM10_EDGE_ADC;
	#ifdef DEBUG_P
    printf("PWMADPOS = %d;\r\n",PWM10_EDGE_ADC);
	#endif
	#ifdef EDGE_ADC_MODE
        PWMADPOS = EDGE_ADC_MODE;
		#ifdef DEBUG_P
		printf("PWM10ADEN= %d;\r\n",EDGE_ADC_MODE);
		#endif
	#else
		PWMADPOS = 0;
		#ifdef DEBUG_P
		printf("PWM10ADEN= 0;\r\n");
		#endif
	#endif
#else
    PWM10ADEN  = 0;
	#ifdef DEBUG_P
	printf("PWMADPOS = 0;\r\n");
	#endif
#endif

#ifdef EDGE_ADC_DELAY
    PWM1CON1 = EDGE_ADC_DELAY;
	#ifdef DEBUG_P
	printf("PWM1CON1 = 0x%02X;\r\n",PWM1CON1);
	#endif
#else
    PWM1CON1 = 127;
	#ifdef DEBUG_P
	printf("PWM1CON1  = 127;\r\n");
	#endif
#endif

    printf("/*********CCP_PWM*********/\r\n");
	Temp = 0;Temp = PWM1CON1;
	printf("PWM1CON1 = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = PWM1CON0;
	printf("PWM1CON0 = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = PMS;Temp = 0;Temp = PMS;
	Temp = 0;Temp = PMS;Temp = 0;Temp = PMS;
	printf("PMS      = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = PXC;
	printf("PXC      = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = DTC;
	printf("DTC      = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = POLS;
	printf("POLS     = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = PME;
	printf("PME      = 0x%02X; \r\n",Temp);
	Temp = 0;

#ifdef CCP_PWM
	     if(CCP_PWM == TRUE) CCPCON  = 0x02;
	else if(CCP_PWM == FALSE)CCPCON &= 0xFD;
#else
    CCPCON &= 0xFD;
	#ifdef DEBUG_P
	Temp = 0;Temp = CCPCON;
	printf("CCPCON   = 0x%02X; \r\n",Temp);
	Temp = 0;
	#endif
#endif
    printf("/*********CCP_PWM*********/\r\n");
}


/*******************************************************************************
* Description    : TIMER3_四路同周期不同占空比PWM初始化
* Input          : None.
* Return         : None.
* Note           : 需转到periph.文件"TIMER3_PWM宏定义设置"区对需要的功能进行设
*                  置，然后在执行该初始化程序
*                  !!!可单独使能或者关闭每一路PWM
*                  !!!其中PWM2_3_4可配合CCP产生三组互补PWM模块调制输出
*                  !!!每一路PWM可分别映射到四组I/O口:
*                     PWM5_OUT:PA2、PB1、PC0、PC4
*                     PWM4_OUT:PA3、PB0、PC1、PC5
*                     PWM3_OUT:PA0、PA4、PB5、PC2
*                     PWM2_OUT:PA1、PA5、PB2、PC3
*******************************************************************************/
void TIMER3_PWM_Config()
{
	unsigned char Temp = 0;

    PWM2H = 0X00;
	PWM2L = 0X00;
	PWM3H = 0X00;
	PWM3L = 0X00;
	PWM4H = 0X00;
	PWM4L = 0X00;
	PWM5H = 0X00;
	PWM5L = 0X00;

    #ifdef T3PWM5
        PWM5EN = T3PWM5;
		#ifdef DEBUG_T3
		printf("PWM5EN    = %d;\r\n",T3PWM5);
		#endif
		#ifdef T3PWM5_OUT
		    PWM5OEN = T3PWM5_OUT;
			#ifdef DEBUG_T3
			printf("PWM5OEN   = %d;\r\n",T3PWM5_OUT);
			#endif
			#ifdef PWM5_OUT_I_O
			     if(PWM5_OUT_I_O == PWM5_OUT_PA2){TRISA2 = 0;P5CS1 = 0;P5CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISA2    = 0;\r\nP5CS1     = 0;\r\nP5CS0     = 0;\r\n");
					#endif
				 }
			else if(PWM5_OUT_I_O == PWM5_OUT_PB1){TRISB1 = 0;P5CS1 = 0;P5CS0 = 1;
					#ifdef DEBUG_T3
					printf("TRISB1    = 0;\r\nP5CS1     = 0;\r\nP5CS0     = 1;\r\n");
					#endif
			}
			else if(PWM5_OUT_I_O == PWM5_OUT_PC0){TRISC0 = 0;P5CS1 = 1;P5CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISC0    = 0;\r\nP5CS1     = 1;\r\nP5CS0     = 0;\r\n");
					#endif
		    }
			else if(PWM5_OUT_I_O == PWM5_OUT_PC4){TRISC4 = 0;P5CS1 = 1;P5CS0 = 1;
					#ifdef DEBUG_T3
					printf("TRISC4    = 0;\r\nP5CS1     = 1;\r\nP5CS0     = 1;\r\n");
					#endif
			}
			else {TRISA2 = 0;P5CS1 = 0;P5CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISA2    = 0;\r\nP5CS1     = 0;\r\nP5CS0     = 0;\r\n");
					#endif
		    }
			#else
			    TRISA2 = 0;P5CS1 = 0;P5CS0 = 0;
				#ifdef DEBUG_T3
				printf("TRISA2    = 0;\r\nP5CS1     = 0;\r\nP5CS0     = 0;\r\n");
				#endif
			#endif
		#else
		    PWM5OEN = 0;
			#ifdef DEBUG_T3
			printf("PWM5OEN   = 0;\r\n");
			#endif
		#endif
	#else
        PWM5EN = 0;
		#ifdef DEBUG_T3
		printf("PWM5EN    = 0;\r\n");
		#endif
	#endif

    #ifdef T3PWM4
        PWM4EN = T3PWM4;
		#ifdef DEBUG_T3
		printf("PWM4EN    = %d;\r\n",T3PWM4);
		#endif
		#ifdef T3PWM4_OUT
		    PWM4OEN = T3PWM4_OUT;
			#ifdef DEBUG_T3
			printf("PWM4OEN   = %d;\r\n",T3PWM4_OUT);
			#endif
			#ifdef PWM4_OUT_I_O
			     if(PWM4_OUT_I_O == PWM4_OUT_PA3){TRISA3 = 0;P4CS1 = 0;P4CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISA3    = 0;\r\nP4CS1     = 0;\r\nP4CS0     = 0;\r\n");
					#endif
				 }
			else if(PWM4_OUT_I_O == PWM4_OUT_PB0){TRISB0 = 0;P4CS1 = 0;P4CS0 = 1;
					#ifdef DEBUG_T3
					printf("TRISB0    = 0;\r\nP4CS1     = 0;\r\nP4CS0     = 1;\r\n");
					#endif
			}
			else if(PWM4_OUT_I_O == PWM4_OUT_PC1){TRISC1 = 0;P4CS1 = 1;P4CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISC1    = 0;\r\nP4CS1     = 1;\r\nP4CS0     = 0;\r\n");
					#endif
			}
			else if(PWM4_OUT_I_O == PWM4_OUT_PC5){TRISC5 = 0;P4CS1 = 1;P4CS0 = 1;
					#ifdef DEBUG_T3
					printf("TRISC5    = 0;\r\nP4CS1     = 0;\r\nP4CS0     = 1;\r\n");
					#endif
			}
			else {TRISA3 = 0;P4CS1 = 0;P4CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISA3    = 0;\r\nP4CS1     = 0;\r\nP4CS0     = 0;\r\n");
					#endif
			}
			#else
			    TRISA3 = 0;P4CS1 = 0;P4CS0 = 0;
				#ifdef DEBUG_T3
				printf("TRISA3    = 0;\r\nP4CS1     = 0;\r\nP4CS0     = 0;\r\n");
				#endif
			#endif
		#else
		    PWM4OEN = 0;
			#ifdef DEBUG_T3
			printf("PWM4OEN   = 0;\r\n");
			#endif
		#endif
	#else
        PWM4EN = 0;
		#ifdef DEBUG_T3
		printf("PWM4EN    = 0;\r\n");
		#endif
	#endif

    #ifdef T3PWM3
        PWM3EN = T3PWM3;
		#ifdef DEBUG_T3
		printf("PWM3EN    = %d;\r\n",T3PWM3);
		#endif
		#ifdef T3PWM3_OUT
		    PWM3OEN = T3PWM3_OUT;
			#ifdef DEBUG_T3
			printf("PWM3OEN   = %d;\r\n",T3PWM3_OUT);
			#endif
			#ifdef PWM3_OUT_I_O
			     if(PWM3_OUT_I_O == PWM3_OUT_PA0){TRISA0 = 0;P3CS1 = 0;P3CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISA0    = 0;\r\nP3CS1     = 0;\r\nP3CS0     = 0;\r\n");
					#endif
				 }
			else if(PWM3_OUT_I_O == PWM3_OUT_PA4){TRISA4 = 0;P3CS1 = 0;P3CS0 = 1;
					#ifdef DEBUG_T3
					printf("TRISA4    = 0;\r\nP3CS1     = 0;\r\nP3CS0     = 1;\r\n");
					#endif
			}
			else if(PWM3_OUT_I_O == PWM3_OUT_PB5){TRISB5 = 0;P3CS1 = 1;P3CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISB5    = 0;\r\nP3CS1     = 1;\r\nP3CS0     = 0;\r\n");
					#endif
			}
			else if(PWM3_OUT_I_O == PWM3_OUT_PC2){TRISC2= 0;P3CS1 = 1;P3CS0 = 1;
					#ifdef DEBUG_T3
					printf("TRISC2    = 0;\r\nP3CS1     = 1;\r\nP3CS0     = 1;\r\n");
					#endif
			}
			else {TRISA0 = 0;P3CS1 = 0;P3CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISA0    = 0;\r\nP3CS1     = 0;\r\nP3CS0     = 0;\r\n");
					#endif
			}
			#else
			    TRISA0 = 0;P3CS1 = 0;P3CS0 = 0;
			    #ifdef DEBUG_T3
				printf("TRISA0    = 0;\r\nP3CS1     = 0;\r\nP3CS0     = 0;\r\n");
				#endif
			#endif
		#else
		    PWM3OEN = 0;
			#ifdef DEBUG_T3
			printf("PWM3OEN   = 0;\r\n");
			#endif
		#endif
	#else
        PWM3EN = 0;
		#ifdef DEBUG_T3
		printf("PWM3EN    = 0;\r\n");
		#endif
	#endif

    #ifdef T3PWM2
        PWM2EN = T3PWM2;
		#ifdef DEBUG_T3
		printf("PWM2EN    = %d;\r\n",T3PWM2);
		#endif
		#ifdef T3PWM2_OUT
		    PWM2OEN = T3PWM2_OUT;
			#ifdef DEBUG_T3
			printf("PWM2OEN   = %d;\r\n",T3PWM2_OUT);
			#endif
			#ifdef PWM2_OUT_I_O
			     if(PWM2_OUT_I_O == PWM2_OUT_PA1){TRISA1 = 0;P2CS1 = 0;P2CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISA1    = 0;\r\nP2CS1     = 0;\r\nP2CS0     = 0;\r\n");
					#endif
				 }
			else if(PWM2_OUT_I_O == PWM2_OUT_PA5){TRISA5 = 0;P2CS1 = 0;P2CS0 = 1;
					#ifdef DEBUG_T3
					printf("TRISA5    = 0;\r\nP2CS1     = 0;\r\nP2CS0     = 1;\r\n");
					#endif
			}
			else if(PWM2_OUT_I_O == PWM2_OUT_PB2){TRISB2 = 0;P2CS1 = 1;P2CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISB2    = 0;\r\nP2CS1     = 1;\r\nP2CS0     = 0;\r\n");
					#endif
			}
			else if(PWM2_OUT_I_O == PWM2_OUT_PC3){TRISC3 = 0;P2CS1 = 1;P2CS0 = 1;
					#ifdef DEBUG_T3
					printf("TRISC3    = 0;\r\nP2CS1     = 1;\r\nP2CS0     = 1;\r\n");
					#endif
			}
			else {TRISA1 = 0;P2CS1 = 0;P2CS0 = 0;
					#ifdef DEBUG_T3
					printf("TRISA1    = 0;\r\nP2CS1     = 0;\r\nP2CS0     = 0;\r\n");
					#endif
			}
			#else
			    TRISA1 = 0;P2CS1 = 0;P2CS0 = 0;
				#ifdef DEBUG_T3
				printf("TRISA1    = 0;\r\nP2CS1     = 0;\r\nP2CS0     = 0;\r\n");
				#endif
			#endif
		#else
		    PWM2OEN = 0;
			#ifdef DEBUG_T3
			printf("PWM2OEN   = 0;\r\n");
			#endif
		#endif
	#else
        PWM2EN = 0;
		#ifdef DEBUG_T3
		printf("PWM2EN    = 0;\r\n");
		#endif
	#endif


    #ifdef T3PWM5_POLS
	    POLS5 = T3PWM5_POLS;
		#ifdef DEBUG_T3
		printf("POLS5     = %d;\r\n",T3PWM5_POLS);
		#endif
	#else
        POLS5 = 0;
		#ifdef DEBUG_T3
		printf("POLS5     = 0;\r\n");
		#endif
	#endif

	#ifdef T3PWM4_POLS
	    POLS4 = T3PWM4_POLS;
		#ifdef DEBUG_T3
		printf("POLS4     = %d;\r\n",T3PWM4_POLS);
		#endif
	#else
        POLS4 = 0;
		#ifdef DEBUG_T3
		printf("POLS4     = 0;\r\n");
		#endif
	#endif

	#ifdef T3PWM3_POLS
	    POLS3 = T3PWM3_POLS;
		#ifdef DEBUG_T3
		printf("POLS3     = %d;\r\n",T3PWM3_POLS);
		#endif
	#else
        POLS3 = 0;
		#ifdef DEBUG_T3
		printf("POLS3     = 0;\r\n");
		#endif
	#endif

	#ifdef T3PWM2_POLS
	    POLS2 = T3PWM2_POLS;
		#ifdef DEBUG_T3
		printf("POLS2     = %d;\r\n",T3PWM2_POLS);
		#endif
	#else
        POLS2 = 0;
		#ifdef DEBUG_T3
		printf("POLS2     = 0;\r\n");
		#endif
	#endif

    printf("/********TIMER3_PWM*******/\r\n");
	Temp = 0;Temp = PWM2CON0;
	printf("PWM2CON0 = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = PWM2CON1;
	printf("PWM2CON1 = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = PWM2CON3;
	printf("PWM2CON3 = 0x%02X; \r\n",Temp);
	Temp = 0;
    printf("/********TIMER3_PWM*******/\r\n");
}

/*******************************************************************************
* Description    : Timer2_PWM占空比设置
* Input          : Timer2_PWM的占空比 （0%-99%）
* Return         : None.
* Note           : 该函数可以设置Timer1_PWM的占空比
*                  *占空比=[PR2H:PR2L]*(Duty/100)
*******************************************************************************/
void Config_PWM_Duty(unsigned short Duty)
{
   unsigned char PWMH = 0;
   unsigned char PWML = 0;

   Duty     = Duty-1;
   PWMH     = (Duty >> 8) & 0xFF;
   PWML     = Duty & 0xFF;

   CCPR1LH  = PWMH;
   CCPR1L   = PWML;   //设置PWM占空比
}

/*******************************************************************************
* Description    : Timer3_PWM5占空比设置
* Input          : Timer3_PWM5的占空比
* Return         : None.
* Note           : 该函数可以设置Timer1_PWM的占空比
*                  *占空比=[PR3H:PR3L]*(Duty/100)
*******************************************************************************/
void T3_PWM5_Duty(unsigned short Duty)
{
   unsigned char PWMH = 0;
   unsigned char PWML = 0;

   Duty     = Duty-1;
   PWMH     = (Duty >> 8) & 0xFF;
   PWML     = Duty & 0xFF;

   PWM5H    = PWMH;
   PWM5L    = PWML;   //设置PWM占空比
}

/*******************************************************************************
* Description    : Timer3_PWM4占空比设置
* Input          : Timer3_PWM4的占空比
* Return         : None.
* Note           : 该函数可以设置Timer1_PWM的占空比
*                  *占空比=[PR3H:PR3L]*(Duty/100)
*******************************************************************************/
void T3_PWM4_Duty(unsigned short Duty)
{
   unsigned char PWMH = 0;
   unsigned char PWML = 0;

   Duty     = Duty-1;
   PWMH     = (Duty >> 8) & 0xFF;
   PWML     = Duty & 0xFF;

   PWM4H    = PWMH;
   PWM4L    = PWML;   //设置PWM占空比
}

/*******************************************************************************
* Description    : Timer3_PWM3占空比设置
* Input          : Timer3_PWM3的占空比
* Return         : None.
* Note           : 该函数可以设置Timer1_PWM的占空比
*                  *占空比=[PR3H:PR3L]*(Duty/100)
*******************************************************************************/
void T3_PWM3_Duty(unsigned short Duty)
{
   unsigned char PWMH = 0;
   unsigned char PWML = 0;

   Duty     = Duty-1;
   PWMH     = (Duty >> 8) & 0xFF;
   PWML     = Duty & 0xFF;

   PWM3H    = PWMH;
   PWM3L    = PWML;   //设置PWM占空比
}

/*******************************************************************************
* Description    : Timer3_PWM2占空比设置
* Input          : Timer3_PWM2的占空比
* Return         : None.
* Note           : 该函数可以设置Timer1_PWM的占空比
*                  *占空比=[PR3H:PR3L]*(Duty/100)
*******************************************************************************/
void T3_PWM2_Duty(unsigned short Duty)
{
   unsigned char PWMH = 0;
   unsigned char PWML = 0;

   Duty     = Duty-1;
   PWMH     = (Duty >> 8) & 0xFF;
   PWML     = Duty & 0xFF;

   PWM2H    = PWMH;
   PWM2L    = PWML;   //设置PWM占空比
}

//==============================================================================================
// ----Function: GPIO初始化设置
// --Parameters: None
// -----Returns: None
//---------Note: 该函数为内部函数，当调用Config_ADC或Config_AUTO_ADC函数后可自动初始化AD通道对应
//               的GPIO
//==============================================================================================
void Config_AD_GPIO(unsigned char TEMP_c)
{
   //将对应通道的I/O口设置为输入模式，关闭上下拉，关闭开漏，然后使能该口的模拟功能
   switch(TEMP_c)
   {
	  case  0:{TRISA3 = 1;PA3PD = 1;PA3PU = 1;PA3OD = 0;PA3AEN = 1;}break;
	  case  1:{TRISA2 = 1;PA2PD = 1;PA2PU = 1;PA2OD = 0;PA2AEN = 1;}break;
	  case  2:{TRISA1 = 1;PA1PD = 1;PA1PU = 1;PA1OD = 0;PA1AEN = 1;}break;
	  case  3:{TRISA0 = 1;PA0PD = 1;PA0PU = 1;PA0OD = 0;PA0AEN = 1;}break;
	  case  4:{TRISB0 = 1;PB0PD = 1;PB0PU = 1;PB0OD = 0;PB0AEN = 1;}break;
	  case  5:{TRISB1 = 1;PB1PD = 1;PB1PU = 1;PB1OD = 0;PB1AEN = 1;}break;
	  case  6:{TRISB5 = 1;PB5PD = 1;PB5PU = 1;PB5OD = 0;PB5AEN = 1;}break;
	  case  7:{TRISC1 = 1;PC1PD = 1;PC1PU = 1;PC1OD = 0;PC1AEN = 1;}break;
	  case  8:{TRISC0 = 1;PC0PD = 1;PC0PU = 1;PC0OD = 0;PC0AEN = 1;}break;
	  case  9:{TRISA5 = 1;PA5PD = 1;PA5PU = 1;PA5OD = 0;PA5AEN = 1;}break;
	  case 13:{TRISB2 = 1;PB2PD = 1;PB2PU = 1;PB2OD = 0;PB2AEN = 1;}break;
	  default: break;
   }
}

//==============================================================================================
// ----Function: Config_ADC
// --Parameters:
//【Channel】：AD转换通道设置（可选如下）
//
//            AD_CH0_PA3： ADC通道 0（PA3）
//            AD_CH1_PA2： ADC通道 1（PA2）
//            AD_CH2_PA1： ADC通道 2（PA1）
//            AD_CH3_PA0： ADC通道 3（PA0）
//            AD_CH4_PB0： ADC通道 4（PB0）
//            AD_CH5_PB1： ADC通道 5（PB1）
//            AD_CH6_PB5： ADC通道 6（PB5）
//            AD_CH7_PC1： ADC通道 7（PC1）
//            AD_CH8_PC0： ADC通道 8（PC0）
//            AD_CH9_PA5： ADC通道 9（PA5）
//   AD_CH10_BUFFER_UNIT： ADC通道10（BUFFER_UNIT）
//        AD_CH11_OP1OUT： ADC通道11（OP1OUT）
//        AD_CH12_OP0OUT： ADC通道12（OP0OUT）
//           AD_CH13_PB2： ADC通道13（PB2）
//       AD_CH14_DAC0OUT： ADC通道14（DAC0OUT）
//        AD_CH15_FVROUT： ADC通道15（FVROUT）
//
//【Vref_Volt】：ADC参考电压选择（可选如下）
//
//           AD_Vref_FVR：参考电压为FVR
//           AD_Vref_VCC：参考电压为VCC
//       AD_Vref_OP0_OUT：参考电压为OP0_OUT
//           AD_Vref_PB0：参考电压为PB0口输入电压
//
//【AD_ACQT】：ADC采集时间选择（可选如下）
//
//                AD_0TAD： 0 TAD
//                AD_2TAD： 2 TAD
//                AD_4TAD： 4 TAD
//                AD_6TAD： 6 TAD
//                AD_8TAD： 8 TAD
//               AD_10TAD：10 TAD
//               AD_12TAD：12 TAD
//               AD_14TAD：14 TAD
//
//【AD_CS】：ADC转换时钟选择（可选如下）
//
//   AD_FOSC_16_or_FOSC_2：FOSC/16(ADSP=0) ，FOSC/2(ADSP=1)
//   AD_FOSC_32_or_FOSC_8：FOSC/32 (ADSP=0)，FOSC/8(ADSP=1)
// AD_FOSC_256_or_FOSC_32：FOSC/256(ADSP=0)，FOSC/32(ADSP=1)
//             AD_OSC_32K：内部 32K OSC
//   AD_FOSC_32_or_FOSC_4：FOSC/32(ADSP=0) ，FOSC/4(ADSP=1)
// AD_FOSC_128_or_FOSC_16：FOSC/128(ADSP=0)，FOSC/16(ADSP=1)
// AD_FOSC_512_or_FOSC_64：FOSC/512(ADSP=0)，FOSC/64(ADSP=1)
//          AD_OSC_1D024M：内部 1.024M_OSC
//
//【AD_Pri_INT】：AD中断设置
//
//				  INT_OFF：禁用AD中断
//				H_Pri_INT：使能AD高优先级中断:
//			    L_Pri_INT：使能AD低优先级中断
//
// -----Returns: None
//---------Note: 该函数可设置AD转换的通道、参考电压、采集时间、转换时钟并使能ADC模块
//==============================================================================================
void Config_ADC(unsigned char Channel,unsigned char Vref_Volt,unsigned char AD_ACQT,unsigned char AD_CS,unsigned char AD_Pri_INT)
{
   unsigned char Temp = 0;

   temp_s0 = 0;
   temp_s1 = 0;

   //以下为超限判断，如果超出则设置一个默认值，防止用户设置超过范围的值导致系统出错
   if(Channel   > 15 )Channel   = AD_CH0_PA3;
   if(Vref_Volt >  3 )Vref_Volt = AD_Vref_VCC;
   if(AD_ACQT   >  7 )AD_ACQT   = AD_14TAD;
   if(AD_CS     >  7 )AD_CS     = AD_FOSC_512_or_FOSC_64;

   //设置AD转换使用到的GPIO通道
   Config_AD_GPIO(Channel);

   temp_s0 |= Channel   << 2;  //写入A/D转换通道设置值到ADCON0[5:2]
   temp_s1 |= Vref_Volt << 6;  //写入A/D转换参考电压设置到ADCON1[7:6]
   temp_s1 |= AD_ACQT   << 3;  //写入A/D转换时间设置到ADCON1[5:3]
   temp_s1 |= AD_CS;           //写入A/D转换时钟设置到ADCON1[2:0]

   ADCON0 = temp_s0;
   ADCON1 = temp_s1;

   ADFM    = 0;               //ADC转结果右对齐，即ADRESH = {4’b0,adc【11:8】}，ADRESL = adc【7:0】
   ADON    = 1;               //使能ADC模块

    printf("/***********ADC***********/\r\n");
    Temp = 0;Temp = ADCON0;
	printf("ADCON0   = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCON1;
	printf("ADCON1   = 0x%02X; \r\n",Temp);

	Temp = 0;Temp = ADCMP0H;
	printf("PADCMP0H = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCMP1H;
	printf("ADCMP1H  = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCMP01L;
	printf("ADCMP01L = 0x%02X; \r\n",Temp);
	Temp = 0;

   	//AD中断设置
	     if(AD_Pri_INT == H_Pri_INT){ADIF = 0;ADIP = 1;ADIE = 1;printf("ADIF     = 0;\r\nADIP     = 1;\r\nADIE     = 1;\r\n");}
	else if(AD_Pri_INT == L_Pri_INT){ADIF = 0;ADIP = 0;ADIE = 1;printf("ADIF     = 0;\r\nADIP     = 0;\r\nADIE     = 1;\r\n");}
	else {ADIF = 0;ADIP = 1;ADIE = 0;printf("ADIF     = 0;\r\nADIP     = 1;\r\nADIE     = 0;\r\n");}

    printf("/***********ADC***********/\r\n");
}

//==============================================================================================
// ----Function: Config_AUTO_ADC
// --Parameters:
//【Channel】：AD转换通道设置（可选如下）
//
//            AD_CH0_PA3： ADC通道 0（PA3）
//            AD_CH1_PA2： ADC通道 1（PA2）
//            AD_CH2_PA1： ADC通道 2（PA1）
//            AD_CH3_PA0： ADC通道 3（PA0）
//            AD_CH4_PB0： ADC通道 4（PB0）
//            AD_CH5_PB1： ADC通道 5（PB1）
//            AD_CH6_PB5： ADC通道 6（PB5）
//            AD_CH7_PC1： ADC通道 7（PC1）
//            AD_CH8_PC0： ADC通道 8（PC0）
//            AD_CH9_PA5： ADC通道 9（PA5）
//   AD_CH10_BUFFER_UNIT： ADC通道10（BUFFER_UNIT）
//        AD_CH11_OP1OUT： ADC通道11（OP1OUT）
//        AD_CH12_OP0OUT： ADC通道12（OP0OUT）
//           AD_CH13_PB2： ADC通道13（PB2）
//       AD_CH14_DAC0OUT： ADC通道14（DAC0OUT）
//        AD_CH15_FVROUT： ADC通道15（FVROUT）
//
//【Vref_Volt】：ADC参考电压选择（可选如下）
//
//           AD_Vref_FVR：参考电压为FVR
//           AD_Vref_VCC：参考电压为VCC
//       AD_Vref_OP0_OUT：参考电压为OP0_OUT
//           AD_Vref_PB0：参考电压为PB0口输入电压
//
//【TIM1_Dly】：定时自动采集时间设置
//              设置范围：0-2048
//              单位:毫秒(ms)
//
//【AD_ACQT】 ：开始采集后延迟时间设置
//              计算公式:T = ACQT[6:0]*2*当前的AD时钟
//              设置范围：0-127
//
//【AD_CS】：ADC转换时钟选择（可选如下）
//
//   AD_FOSC_16_or_FOSC_2：FOSC/16(ADSP=0) ，FOSC/2(ADSP=1)
//   AD_FOSC_32_or_FOSC_8：FOSC/32 (ADSP=0)，FOSC/8(ADSP=1)
// AD_FOSC_256_or_FOSC_32：FOSC/256(ADSP=0)，FOSC/32(ADSP=1)
//             AD_OSC_32K：内部 32K OSC
//   AD_FOSC_32_or_FOSC_4：FOSC/32(ADSP=0) ，FOSC/4(ADSP=1)
// AD_FOSC_128_or_FOSC_16：FOSC/128(ADSP=0)，FOSC/16(ADSP=1)
// AD_FOSC_512_or_FOSC_64：FOSC/512(ADSP=0)，FOSC/64(ADSP=1)
//            AD_OSC_256K：内部 256K OSC
//
//【AD_Pri_INT】：AD中断设置
//
//				  INT_OFF：禁用AD中断
//				H_Pri_INT：使能AD高优先级中断:
//			    L_Pri_INT：使能AD低优先级中断
//
// -----Returns: None
//---------Note: 该函数可设置AD定时自动采集功能，以及相关的采集通道、参考电压、采集时间和转换时钟,并使能ADC模块
//               *设置自动采集延迟时间，则AD采集总延迟时间=TIMER1定时时间+ACQT[6:0]延时时间

//==============================================================================================
void Config_TIMER1_AUTO_ADC(unsigned char Channel,unsigned char Vref_Volt,unsigned int TIM1_Dly,unsigned char AD_ACQT,unsigned char AD_CS,unsigned char AD_Pri_INT)
{
   unsigned char Temp = 0;
   unsigned char T1 = 0,T2 = 0;

   temp_s0 = 0;
   temp_s1 = 0;
   temp_s2 = 0;

   //以下为超限判断，如果超出则设置一个默认值，防止用户设置超过范围的值导致系统出错
   if(Channel   > 15 )Channel   = AD_CH0_PA3;
   if(Vref_Volt >  3 )Vref_Volt = AD_Vref_VCC;
   if(AD_ACQT   > 127)AD_ACQT   = 20;
   if(AD_CS     >  7 )AD_CS     = AD_FOSC_512_or_FOSC_64;
   if(TIM1_Dly  >2048)TIM1_Dly  = 200;

   //设置AD转换使用到的GPIO通道
   Config_AD_GPIO(Channel);

   //定时自动采集时间 = (65536-TIM1_Dly)/32000  单位：秒(s)
   TMR1H   = (65536-(TIM1_Dly*32)) >> 8;
   TMR1L   = (65536-(TIM1_Dly*32));
   T1CON0  = 0x43;     	      //低功耗模式下仅低速时钟工作，因此本例程使用低速OSC32K，若用户不用于低功耗时使能自动采集功能，可使用高速时钟，用户可参考TIMER1相关例程自行设置
   T1CON1  = 0x03; 	          //TIMER1模式2:TIMER1工作在定时模式,在定时产生中断时启动ADC采集

   T1 = AD_ACQT >> 3;
   T2 = AD_ACQT & 0x07;

   temp_s0 |= Channel   << 2;  //写入转换通道设置值到ADCON0[5:2]位
   temp_s1 |= Vref_Volt << 6;  //写入转换参考电压设置到ADCON1[7:6]位
   temp_s1 |= T2        << 3;  //写入采集延迟设置到ADCON1[5:3](ACQT[0:2])位
   temp_s1 |= AD_CS;           //写入A/D转换时钟设置到ADCON1[2:0]位

   ADCON0  |= temp_s0;
   ADCON1  |= temp_s1;

   ADFM     = 0;               //ADC转结果右对齐，即ADRESH = {4’b0,adc【11:8】}，ADRESL = adc【7:0】
   ADON     = 1;               //使能AD转换模块

   temp_s2 |= T1        << 4;



    printf("/***********ADC***********/\r\n");
    Temp = 0;Temp = ADCON0;
	printf("ADCON0   = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCON1;
	printf("ADCON1   = 0x%02X; \r\n",Temp);

	Temp = 0;Temp = ADCMP0H;
	printf("PADCMP0H = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCMP1H;
	printf("ADCMP1H  = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCMP01L;
	printf("ADCMP01L = 0x%02X; \r\n",Temp);
	Temp = 0;
   	//AD中断设置
	     if(AD_Pri_INT == H_Pri_INT){ADIF = 0;ADIP = 1;ADIE = 1;printf("ADIF     = 0;\r\nADIP     = 1;\r\nADIE     = 1;\r\n");}
	else if(AD_Pri_INT == L_Pri_INT){ADIF = 0;ADIP = 0;ADIE = 1;printf("ADIF     = 0;\r\nADIP     = 0;\r\nADIE     = 1;\r\n");}
	else {ADIF = 0;ADIP = 1;ADIE = 0;printf("ADIF     = 0;\r\nADIP     = 1;\r\nADIE     = 0;\r\n");}
    printf("/***********ADC***********/\r\n");
}

//==============================================================================================
// ----Function: Config_AUTO_ADC
// --Parameters:
//【Channel】：AD转换通道设置（可选如下）
//
//            AD_CH0_PA3： ADC通道 0（PA3）
//            AD_CH1_PA2： ADC通道 1（PA2）
//            AD_CH2_PA1： ADC通道 2（PA1）
//            AD_CH3_PA0： ADC通道 3（PA0）
//            AD_CH4_PB0： ADC通道 4（PB0）
//            AD_CH5_PB1： ADC通道 5（PB1）
//            AD_CH6_PB5： ADC通道 6（PB5）
//            AD_CH7_PC1： ADC通道 7（PC1）
//            AD_CH8_PC0： ADC通道 8（PC0）
//            AD_CH9_PA5： ADC通道 9（PA5）
//   AD_CH10_BUFFER_UNIT： ADC通道10（BUFFER_UNIT）
//        AD_CH11_OP1OUT： ADC通道11（OP1OUT）
//        AD_CH12_OP0OUT： ADC通道12（OP0OUT）
//           AD_CH13_PB2： ADC通道13（PB2）
//       AD_CH14_DAC0OUT： ADC通道14（DAC0OUT）
//        AD_CH15_FVROUT： ADC通道15（FVROUT）
//
// -----Returns: None
//---------Note: None
//==============================================================================================
void ADC_CH_ICR(unsigned char Channel)
{
    //以下为超限判断，如果超出则设置一个默认值，防止用户设置超过范围的值导致系统出错
	if(Channel   > 15 )Channel   = AD_CH0_PA3;

    //设置AD转换使用到的GPIO通道
    Config_AD_GPIO(Channel);
}

//==============================================================================================
// ----Function: Config_ADCMP_Interrupt
// --Parameters:
//【ADCMP_MODE】:ADC比较模式设置
//
// AD_CMP_MODE_0：ADC比较模式0,即“采集值大于ADCMP1[H:L]产生中断ADCMP1IF,小于ADCMP0[H:L]产生中断ADCMP0IF”;
// AD_CMP_MODE_1：ADC比较模式1,即“采集值小于ADCMP1[H:L]且大于ADCMP0[H:L]，产生中断ADCMP0IF”;
//
//【ADCMP_ACN】:当ADC采样值符合条件达到指定次数时,触发比较中断标志ADCMP0IF
//
//   AD_CMP_ACN1：当ADC采样值与比较值符合条件1次时,触发比较中断标志ADCMP0IF
//   AD_CMP_ACN2：当ADC采样值与比较值符合条件2次时,触发比较中断标志ADCMP0IF
//   AD_CMP_ACN4：当ADC采样值与比较值符合条件4次时,触发比较中断标志ADCMP0IF
//   AD_CMP_ACN8：当ADC采样值与比较值符合条件8次时,触发比较中断标志ADCMP0IF
//
//【Value_1】:ADC比较器的比较值(设置范围0-4095),详见手册比较模式设置说明
//【Value_0】:ADC比较器的比较值(设置范围0-4095),详见手册比较模式设置说明
//
//【AD_Pri_INT】：AD中断设置
//
//				  INT_OFF：禁用AD中断
//				H_Pri_INT：使能AD高优先级中断:
//			    L_Pri_INT：使能AD低优先级中断
//
// -----Returns: None
//---------Note: 该函数可设置AD转换的比较中断功能

//==============================================================================================
void Config_ADCMP_Interrupt(unsigned char ADCMP_MODE,unsigned char ADCMP_ACN,unsigned short Value_1,unsigned short Value_0,unsigned char AD_Pri_INT )
{
   unsigned char Temp_0H  = 0;
   unsigned char Temp_1H  = 0;
   unsigned char Temp_0L  = 0;
   unsigned char Temp_1L  = 0;
   unsigned char Temp_01L = 0;
   unsigned char Temp     = 0;
   temp_s0 = 0;

   //以下为超限判断，如果超出则设置一个默认值，防止用户设置超过范围的值导致系统出错
   if(ADCMP_MODE > 1)ADCMP_MODE = AD_CMP_MODE_0;
   if(ADCMP_ACN  > 4)ADCMP_ACN  = AD_CMP_ACN1;

   Temp_0H = (unsigned char)(Value_0 >> 4);
   Temp_1H = (unsigned char)(Value_1 >> 4);
   Temp_0L = (unsigned char)(Value_1 & 0x0f);
   Temp_1L = (unsigned char)(Value_0 & 0x0f);
   Temp_01L= (Temp_0L << 4)|Temp_1L;

   ADCMP0H  = Temp_0H;              //写入比较低值的前八位到ADCMP0H[7:0]位
   ADCMP1H  = Temp_1H;              //写入比较高值的前八位到ADCMP1H[7:0]位
   ADCMP01L = Temp_01L;             //写入比较低值的后四位到ADCMP01L[3:0]位,写入比较高值的后四位到ADCMP01L[7:4]位

   ADCMPMODE= ADCMP_MODE;           //写入比较模式设置到ADCON0.6位

   temp_s0 |= ADCMP_ACN << 2;


	printf("/***********ADC***********/\r\n");
    Temp = 0;Temp = ADCON0;
	printf("ADCON0   = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCON1;
	printf("ADCON1   = 0x%02X; \r\n",Temp);

	Temp = 0;Temp = ADCMP0H;
	printf("PADCMP0H = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCMP1H;
	printf("ADCMP1H  = 0x%02X; \r\n",Temp);
	Temp = 0;Temp = ADCMP01L;
	printf("ADCMP01L = 0x%02X; \r\n",Temp);
	Temp = 0;


	if(ADCMP_MODE == AD_CMP_MODE_0)
    {
		if(AD_Pri_INT == H_Pri_INT)
		{
			ADCMP0IF = 0;ADCMP0IP = 1;ADCMP0IE = 1;printf("ADCMP0IF     = 0;\r\nADCMP0IP     = 1;\r\nADCMP0IE     = 1;\r\n");
			ADCMP1IF = 0;ADCMP1IP = 1;ADCMP1IE = 1;printf("ADCMP1IF     = 0;\r\nADCMP1IP     = 1;\r\nADCMP1IE     = 1;\r\n");
		}
		else if(AD_Pri_INT == L_Pri_INT)
		{
			ADCMP0IF = 0;ADCMP0IP = 0;ADCMP0IE = 1;printf("ADCMP0IF     = 0;\r\nADCMP0IP     = 0;\r\nADCMP0IE     = 1;\r\n");
			ADCMP1IF = 0;ADCMP1IP = 0;ADCMP1IE = 1;printf("ADCMP1IF     = 0;\r\nADCMP1IP     = 0;\r\nADCMP1IE     = 1;\r\n");
		}
		else
		{
			ADCMP0IF = 0;ADCMP0IP = 1;ADCMP0IE = 1;printf("ADCMP0IF     = 0;\r\nADCMP0IP     = 1;\r\nADCMP0IE     = 1;\r\n");
			ADCMP1IF = 0;ADCMP1IP = 1;ADCMP1IE = 1;printf("ADCMP1IF     = 0;\r\nADCMP1IP     = 1;\r\nADCMP1IE     = 1;\r\n");
		}
      ADCMP0IF = 0;ADCMP1IF = 0;    //清除中断标志
	  ADCMP0IE = 1;ADCMP1IE = 1;    //开启ADC比较中断
    }else if(ADCMP_MODE == AD_CMP_MODE_1)
    {
		if(AD_Pri_INT == H_Pri_INT)
		{
			ADCMP0IF = 0;ADCMP0IP = 1;ADCMP0IE = 1;printf("ADCMP0IF     = 0;\r\nADCMP0IP     = 1;\r\nADCMP0IE     = 1;\r\n");
		}
		else if(AD_Pri_INT == L_Pri_INT)
		{
			ADCMP0IF = 0;ADCMP0IP = 0;ADCMP0IE = 1;printf("ADCMP0IF     = 0;\r\nADCMP0IP     = 0;\r\nADCMP0IE     = 1;\r\n");
		}
		else
		{
			ADCMP0IF = 0;ADCMP0IP = 1;ADCMP0IE = 1;printf("ADCMP0IF     = 0;\r\nADCMP0IP     = 1;\r\nADCMP0IE     = 1;\r\n");
		}
    }
	printf("/***********ADC***********/\r\n");
}

//==============================================================================================
// ----Function: 启动AD转换
// --Parameters: None
// -----Returns: None
//---------Note: 每次转换前需调用该函数以启动AD转换
//==============================================================================================
void ADC_Start(void)
{
   GO = 1;
}

//==============================================================================================
// ----Function: ADC_SampleFilter
// --Parameters: None
// -----Returns: None
//---------Note: 该函数用于AD转转换的结果获取
//               *该函数采用了Time_OUT方式防止AD转换因为静电等原因导致的运行异常，一旦出现这种情况则重新启动AD转换；
//               *该函数使用了平滑滤波算法，以保证输出的数据稳定，该算法不一定适用于所有情况，请更具实际情况选择对应的算法；
//==============================================================================================
volatile unsigned short VoltBuf[8] = 0;
volatile unsigned char  VoltInx    = 0;
unsigned short ADC_SampleFilter(void)
{
   unsigned char  i,j;
   unsigned short Volt 		 = 0;
   unsigned char  Time_Out   = 0;
   unsigned short Sum        = 0;

   for(j = 0;j<=5;j++)
   {
	  GO = 1;                 //启动一次转换
	  Time_Out = 100;         //设置超时时间
	  while(GO)               //等待转换结束
	  {
		 Time_Out--;          //等待超时
		 if(Time_Out == 0)    //防止程序跑到这里死掉了
		 {
			ADON = 0;         //先关闭AD转换
			GO = 0;           //清除转换标志
			ADON = 1;         //在重新开启AD转换
			GO = 1;           //清除转换标志
		 }
	  }
   }

   Volt = (ADRESH<<8)|ADRESL;//取出AD转换的值
   //以下为平滑滤波算法
   VoltBuf[VoltInx] = Volt;
   VoltInx++;
   if(VoltInx > 7)
   {
	  VoltInx = 0;
   }
   for(i = 0;i <= 7;i++)
   {
	  Sum += VoltBuf[i];
   }
   Volt = (Sum >> 3)&0xFFF;
   return Volt;
}

/*******************************************************************************
* Description    : 设置系统优先级总中断
* Input          : [INT_cfg]:
*                            H_SysPri_INIT_EN : 使能高优先级中断
*                            H_SysPri_INIT_Dis: 禁用高优先级中断
*                            L_SysPri_INIT_EN : 使能低优先级中断
*                            L_SysPri_INIT_Dis: 禁用低优先级中断
* Return         : None.
* Note           : None.
*******************************************************************************/
void System_INIT_Config(unsigned char INT_cfg)
{
	printf("/*********SYS_INT*********/\r\n");
    if(INT_cfg == H_SysPri_INIT_EN)
	{
		printf("IPEN     = 1;\r\nGIEH     = 1;\r\n");
	   	IPEN = 1;	   //使能中断优先级
	    GIEH = 1;      //使能高优先级全局中断
	}else if(INT_cfg == H_SysPri_INIT_Dis)
	{
		printf("IPEN     = 1;\r\nGIEH     = 0;\r\n");
	   	IPEN = 1;	   //使能中断优先级
	    GIEH = 0;      //禁用高优先级全局中断
	}else if(INT_cfg == L_SysPri_INIT_EN)
	{
		printf("IPEN     = 1;\r\nGIEL     = 1;\r\n");
	   	IPEN = 1;	   //使能中断优先级
	    GIEL = 1;      //使能低优先级全局中断
	}else if(INT_cfg == L_SysPri_INIT_Dis)
	{
	    printf("IPEN     = 1;\r\nGIEL     = 0;\r\n");
	   	IPEN = 1;	   //使能中断优先级
	    GIEL = 0;      //禁用低优先级全局中断
	}
	printf("/*********SYS_INT*********/\r\n");
}
